﻿;{
 ; PBData Version 1.1
 ;
 ; Copyright (c) 2008 by Thomas Schulz / ts-soft@web.de
 ; http://www.realsource.de
 ;
 ; The contents of this file are subject To the Mozilla Public License Version
 ; 1.1 (the "License"); you may not use this file except in compliance with
 ; the License. You may obtain a copy of the License at
 ; http://www.mozilla.org/MPL/
 ;
 ; Software distributed under the License is distributed on an "AS IS" basis,
 ; WITHOUT WARRANTY OF ANY KIND, either express Or implied. See the License
 ; For the specific language governing rights And limitations under the
 ; License.
 ;
 ; The Original Code is PBData_Include.pbi
 ;
 ; The Initial Developer of the Original Code is Thomas Schulz.
 ;
 ; Portions created by Thomas Schulz are Copyright (C) 2008
 ; Thomas Schulz. All Rights Reserved.
;}

CompilerIf Defined(uncompress, #PB_Procedure) = #False
CompilerSelect #PB_Compiler_OS
  CompilerCase #PB_OS_Linux
    ImportC #PB_Compiler_Home + "purelibraries/linux/libraries/zlib.a"
  CompilerCase #PB_OS_Windows
    ImportC "zlib.lib"
CompilerEndSelect
  uncompress(*dest, *destLen, *source, sourceLen)
EndImport
CompilerEndIf


Enumeration
  #UDRes_Packer_None
  #UDRes_Packer_jCalg1
  #UDRes_Packer_zip
EndEnumeration

CompilerIf Defined(UDResPack, #PB_Structure) = #False
Structure UDResPack
  Size.q
  CRC.q
  Packer.b
  Magic.b[6]
EndStructure
CompilerEndIf

CompilerIf Defined(_UnpackMemory, #PB_Procedure) = #False
Procedure _UnpackMemory(*SourceMemoryID, SourceLength, *DestionationMemoryID, DestLength, Packer = #UDRes_Packer_jCalg1)
  Select Packer
    Case #UDRes_Packer_zip
      If Not uncompress(*DestionationMemoryID, @DestLength, *SourceMemoryID, SourceLength)
        ProcedureReturn #True
      EndIf
  EndSelect
EndProcedure
CompilerEndIf

Define.l PBData_Index
Global PBData_Count
Restore PBData_CatchInfo
Read.l PBData_Count
Global Dim PBDataArray.l(PBData_Count -1)

For PBData_Index = 1 To PBData_Count
  Read.l PBDataArray(PBData_Index - 1)
Next

Procedure PBData_Get(ResNumber)
  Protected Size.l, CRC.l, Packer, I, MemAdr, MemSize
  Protected *Mem.UDResPack, *DestMem

  If ResNumber < 1 : ProcedureReturn #False : EndIf
  If ResNumber > PBData_Count : ProcedureReturn #False : EndIf
  
  For I = 1 To ResNumber - 1
    MemAdr + PBDataArray(I - 1)
  Next
  
  MemSize = PBDataArray(ResNumber - 1)
  
  *Mem = AllocateMemory(MemSize)
  
  If *Mem
    CopyMemory(?PBData_CatchStart + MemAdr, *Mem, MemSize)
    
    If PeekS(@*Mem\Magic[0], 6, #PB_Ascii) <> "PBDATA"

      ProcedureReturn *Mem
    EndIf

    Size    = *Mem\Size
    CRC     = *Mem\CRC
    Packer  = *Mem\Packer

    If Size > 0
      *DestMEM = AllocateMemory(Size)
      If *DestMEM
        If _UnpackMemory(*Mem + SizeOf(UDResPack), MemorySize(*Mem), *DestMEM, Size, Packer) > 0
          FreeMemory(*Mem)
          If CRC32Fingerprint(*DestMEM, Size) = CRC

            ProcedureReturn *DestMEM
          Else
            FreeMemory(*DestMEM)
          EndIf
        Else
          FreeMemory(*DestMEM)
        EndIf
      EndIf
    Else
      FreeMemory(*Mem)
    EndIf
  EndIf
EndProcedure

Procedure.s PBData_GetFileName(ResNumber)
  Protected *Mem = PBData_Get(PBData_Count)
  Protected FileNames.s
  If *Mem
    FileNames = PeekS(*Mem, -1, #PB_UTF8)
    FreeMemory(*Mem)
    ProcedureReturn StringField(FileNames, ResNumber + 1, ",")
  EndIf
EndProcedure

Procedure PBData_GetResNumber(FileName.s, start = 1)
  Protected *Mem = PBData_Get(PBData_Count)
  Protected FileNames.s
  Protected I
  
  If start < 1 : start = 1 : EndIf
  
  If *Mem
    FileNames.s = PeekS(*Mem, -1, #PB_UTF8)
    FreeMemory(*Mem)
    
    For I = start To PBData_Count
      If UCase(StringField(FileNames, I + 1, ",")) = UCase(FileName)
        ProcedureReturn I
      EndIf
    Next
  EndIf
EndProcedure

Procedure PBData_Save(FileName.s, ResNumber)
  Protected FileID
  Protected *Mem

  FileID = CreateFile(#PB_Any, FileName)

  If FileID
    *Mem = PBData_Get(ResNumber)

    If *Mem
      WriteData(FileID, *Mem, MemorySize(*Mem))
      CloseFile(FileID)
      FreeMemory(*Mem)

      ProcedureReturn #True
    EndIf

    CloseFile(FileID)
    DeleteFile(FileName)
  EndIf
EndProcedure

Procedure PBData_CatchSound(Sound, ResNumber)
  Protected *Mem = PBData_Get(ResNumber)
  Protected Result

  If *Mem
    Result = CatchSound(Sound, *Mem, MemorySize(*Mem))
    FreeMemory(*Mem)

    ProcedureReturn Result
  EndIf

EndProcedure

Procedure PBData_CatchImage(Image, ResNumber, Flag = 0)
  Protected *Mem = PBData_Get(ResNumber)
  Protected Result

  If *Mem
    Result = CatchImage(Image, *Mem, MemorySize(*Mem), Flag)
    FreeMemory(*Mem)

    ProcedureReturn Result
  EndIf

EndProcedure

Procedure PBData_CatchSprite(Sprite, ResNumber, Modus = 0)
  Protected *Mem = PBData_Get(ResNumber)
  Protected Result

  If *Mem
    Result = CatchSprite(Sprite, *Mem, Modus)
    FreeMemory(*Mem)

    ProcedureReturn Result
  EndIf

EndProcedure

Procedure PBData_CatchModule(Module, ResNumber)
  Protected *Mem = PBData_Get(ResNumber)
  Protected Result

  If *Mem
    Result = CatchModule(Module, *Mem, MemorySize(*Mem))
    FreeMemory(*Mem)

    ProcedureReturn Result
  EndIf

EndProcedure

;{ PureDataConverter - HexData
DataSection
  PBData_CatchStart:
  WII1_Start:
  Data.l $000004B8,$00000000,$F8EBF04C,$FFFFFFFF,$44425002,$78415441,$C18DEDDA,$10310209,$07B09F45,$48159BC1
  Data.l $81D3DE4E,$5A63D5CC,$61690B48,$5216985A,$C1690880,$B6C2D216,$ADD56710,$30783CC2,$DFE667F0,$0F85CFEE
  Data.l $5EEAF70F,$B2381E7E,$DD7D3E73,$3BD68DB3,$5A945ED6,$A2A46AC9,$98C42A48,$2A4896C8,$14C48948,$08650190
  Data.l $347D2875,$BF7418C6,$6661AD6F,$67392AA8,$02108444,$E22FB9EA,$FA6D3783,$23560CBF,$26585AEB,$02DFC993
  Data.l $4323FB6F
  Data.b $12
  WII1_End:

  WII2_Start:
  Data.l $000004B8,$00000000,$64B7742A,$00000000,$44425002,$78415441,$CB90EDDA,$14310209,$13338F45,$0589DC11
  Data.l $A7DCACC8,$65D6C903,$690B485A,$85A42D21,$B4844029,$C2D30B60,$38DF10B4,$CE1FC0FE,$2E0795C2,$497DCE04
  Data.l $BEED9B78,$B24EC4E2,$99CEAC96,$62C2E330,$7AE2E43E,$D312DB52,$B834DF01,$603EB110,$8B6B47AC,$0C1B168B
  Data.l $ADB46BC6,$367C1931,$E6D03934,$5699CE44,$C44A53E6,$E0210918,$4318C39C,$F104D75D,$F20E4452,$CFB91F52
  Data.l $5D346C41,$5CFEA9E7,$28A28529,$A95E31CB,$8DE799E5,$7B66FEF7,$D3A7EF7E,$FBF8FF7B,$5BA95E4F,$7DEFA943
  Data.l $B57818DF,$CFFE4FFB,$DB08E038
  Data.b $67,$49,$9E
  WII2_End:

  WII3_Start:
  Data.l $000003D0,$00000000,$96899465,$FFFFFFFF,$44425002,$78415441,$BB92BDDA,$1430C20D,$41A22F45,$902889A2
  Data.l $4572057F,$2D2806CF,$0AF05665,$BC15E0AC,$64D00302,$0AF01609,$31D8C159,$88A4BF08,$BA571025,$7F8F8E45
  Data.l $C797CE72,$B1EE631A,$BB1D58C7,$83615D8F,$DCDB7677,$42537203,$7BD55F08,$E1EFBE8F,$16B5839C,$6DB418C6
  Data.l $6C35AD0B,$B58F871C,$DB14ED21,$BB8033A1,$D70C309D,$C29409D7,$ECB6532C,$7CE52528,$73FF6516,$F31097D2
  Data.l $73AB2559,$738C6738,$ECB650EA,$6B1955A4,$EEE8C61A,$8473AB25,$F108C668,$75AB2871,$29D4BAF2,$65239D59
  Data.l $733D27BE,$DF9C6AC9,$292257BD,$B2837FD3,$D909E765
  Data.b $80,$73,$CC
  WII3_End:

  WII4_Start:
  Data.l $000004C8,$00000000,$9F9279B6,$FFFFFFFF,$44425002,$78415441,$3DF273DA,$0600C2C1,$035880DB,$5880D588
  Data.l $1919880A,$40601838,$15821B88,$04182018,$4FFFFFFE,$F77BBE11,$DDEEC32E,$CE6619BB,$D1D0C99C,$9690C1D1
  Data.l $E2E0C696,$A4A0C2E2,$01D0C4A4,$0BB86794,$41FF1DC4,$28710136,$031A6843,$C655CCC3,$95DEEF0C,$2B205D43
  Data.l $A01580CB,$3A8C0F8B,$39395959,$C5D12A6C,$881D4607,$A98F2F27,$789C5D12,$02F2F275,$98F2F202,$89C550EA
  Data.l $06002757,$C550EA98,$31075389,$6D50041D,$3E1F1746,$03B140EA,$0DA661E2,$D5627164,$80BD3F51,$5B004044
  Data.l $2715453A,$32001D4E
  Data.b $09,$79,$E5
  WII4_End:

  WII5_Start:
  Data.l $00000738,$00000000,$E4EDB839,$FFFFFFFF,$44425002,$78415441,$B194CDDA,$1030C20D,$240A8F45,$6F445F62
  Data.l $0D454A29,$4B4A350D,$02BC1599,$AF05782B,$993400C0,$05642BC5,$24318BE3,$A4723605,$C5FA5F28,$B3AFBEFB
  Data.l $DBD728AC,$9E830B65,$93E747CE,$81BCE573,$F61D041D,$8CFBD5DE,$659DAD64,$5D740C63,$506B5A07,$1294814A
  Data.l $BA81A69A,$73B941AE,$D2CACE30,$5A16E726,$671FA009,$E7FBFBE8,$44C0425E,$08EBCE29,$34E31451,$50EEEBC5
  Data.l $8A690A42,$9B1874E7,$AF38C4CE,$43CE13E3,$1D39E29A,$FF3911CE,$BF38C4CE,$596218C3,$67E63222,$F1D79CE2
  Data.l $7E41CB9B,$3BF38A7B,$E88499B4,$FEBCE267,$B6EF12CE,$6E1077D4,$F6DF1A47,$9676E737,$94F81FFA,$74E73FF4
  Data.l $990BEE5E
  Data.b $B6
  WII5_End:

  WII6_Start:
  Data.l $00000218,$00000000,$34BEF55F,$00000000,$44425002,$78415441,$C18F95DA,$1030C44D,$909C1F45,$01C45090
  Data.l $280E7639,$00EEEE27,$2DD1CAF9,$E0B705B8,$0A42DC16,$6816E2E0,$0B6C2D21,$B0AC71DE,$F120A2EC,$7DF92FA5
  Data.l $EFC6678F,$4D9EEA1F,$F137E29F,$7C45F893,$9EBB03C7,$E95FBB1F,$4AEB2A6E,$65C45F2E,$8F8CA421,$D623E709
  Data.l $F8F6427A,$62D170E4,$10AB8CFD,$89A963AB,$AD6A16B5,$94BEF2AC,$9499CE42,$9C042112,$4CF3CC73,$44297B92
  Data.l $59A9320E,$8BC805FA,$DB8A74E5,$F7D369FC,$4D3C378A,$CC6D68C6,$A3735C9E,$1C6A5471,$B59BF27B,$94186A56
  Data.l $8788FAD2,$4C6C474D,$FFF4BFAF,$F3E92DC9,$F2DDFB2E,$C9EFFB5F,$C7FFFFF5,$3E23812D,$4754E603
  Data.b $AC
  WII6_End:

  WII7_Start:
  Data.l $000001F8,$00000000,$B73307F6,$FFFFFFFF,$44425002,$78415441,$B19085DA,$1820C38D,$48BA5F46,$0654AC69
  Data.l $4AB938BB,$DA2706CF,$0AC0AC94,$AC0AC0AC,$61AE01E0,$15E0AC85,$3F23A752,$749F22E1,$3E93DDF6,$FC7C1E09
  Data.l $C7D79F12,$925F1781,$E92CE48B,$BC8E0724,$3E5A9F39,$65E4A968,$611BE521,$E131F19E,$80BAC442,$1C9F0E31
  Data.l $306C5A2E,$0B613718,$4B996284,$52992964,$73F48B0A,$8894A4CE,$C7BDE231,$4D34CB5A,$8B973944,$D52642C8
  Data.l $D21E7BC8,$83DFB86C,$F86FC7EC,$8E376FC1,$AC5FA0C3,$D529CF7E,$B9EFCD0B,$FBEEB56A,$187AD04E,$5CB737DE
  Data.l $D4A7576D,$95B5AE5F,$73FE93AA,$6D9ABFAD,$EC04FEB7,$FA4227BB
  Data.b $47,$D9
  WII7_End:

  WII8_Start:
  Data.l $000001D8,$00000000,$256900C3,$00000000,$44425002,$78415441,$B18F75DA,$1030C20D,$243A5F45,$4E2A889A
  Data.l $7A2A5028,$52DC806F,$E0AF057A,$5782BC15,$5E3400C8,$B2680181,$33982B02,$E1410456,$EFFA5F4B,$2F9DF3EC
  Data.l $5BC347D7,$DC59F137,$86E20F8A,$FB0E8B1D,$45D513EA,$E9899E69,$5C269F8E,$301F5888,$C5B5A3D6,$060D8B45
  Data.l $8EDA35E3,$1B3E0C98,$73981CA6,$2CCCE722,$622529FD,$7010848C,$618C61CE,$9C82471C,$C82445CB,$CF7962A4
  Data.l $CF349C41,$A3A3E7A7,$F25C3F88,$DF2A5A20,$2BDF735C,$5CDBF7D5,$E2DA2772,$56A95772,$AA958FF4,$F2FF74BC
  Data.l $995D7430,$B2B5CDB5,$75CD7DDE,$AFBFEFE3,$C39705F9
  Data.b $47,$B9
  WII8_End:

  WII9_Start:
  Data.l $00000208,$00000000,$6B7B14B3,$00000000,$44425002,$78415441,$C19095DA,$1430C209,$153D7F86,$241E2904
  Data.l $9C907A69,$C90367BC,$C85663D5,$ADE1590A,$80321590,$0AE0AC97,$C42BA15D,$A5115697,$83E0FD0A,$4BC9FFF0
  Data.l $6CDAE5C8,$CF637131,$B3DD91EC,$7178341B,$309ECDD8,$80C3C95B,$2908EF98,$0B8453C1,$8C02EB04,$C1D1F071
  Data.l $060D8591,$02D869C6,$0A916284,$A5192861,$3E7C0C14,$23188CE7,$7BDE0888,$B5A16B58,$1BCF7106,$A9BE0BC1
  Data.l $103CF3CA,$8638C193,$09FEFEE9,$FBCE58BE,$518EA95E,$CE5BB3EA,$10A52A6B,$94842B6D,$DE77EEEF,$08AD3575
  Data.l $EED5A751,$FE6EBE5F,$FFAFF7DA,$3153079F
  Data.b $47,$9C
  WII9_End:

  WII10_Start:
  Data.l $00000208,$00000000,$BDCDE5E1,$FFFFFFFF,$44425002,$78415441,$C19095DA,$1430C209,$093D3F86,$920F1482
  Data.l $27A41EB6,$7240D9EF,$B21598F5,$0AC85642,$7803A159,$D0AE0AC9,$BE215C15,$45228B58,$241F07E8,$097BCBFF
  Data.l $6B375CB9,$B3C4DC5E,$E2771078,$FB130D8A,$D189E8ED,$62061A42,$1EFBE3BA,$07D62217,$6D68F58C,$8362D171
  Data.l $B68D78C1,$CF83261D,$86073E86,$3339C89C,$894A7F48,$04212318,$6318739C,$208EBAE8,$2C883975,$CCA2A6E4
  Data.l $CD7B1073,$70F9E1E3,$730FC37C,$6DB7D979,$77EDB423,$B31F2E65,$AAAA56BA,$A9EBAA94,$AC979F32,$4169284C
  Data.l $97F9A6A9,$FCBF9D2F,$E7FF4BFD,$47611B09
  Data.b $9C
  WII10_End:

  WII11_Start:
  Data.l $00000808,$00000000,$63499551,$00000000,$44425002,$78415441,$CD95D5DA,$1430846D,$95B72784,$F36C5972
  Data.l $591BB16B,$3A1CE439,$D1CD7C88,$2D02D02D,$6C2D02D0,$0B50B901,$C40B6C2D,$098041C6,$921CB048,$9EF0E691
  Data.l $43F6C3E7,$D3CF8F82,$B4BE9D09,$B5DFB4DF,$F09FB55F,$9E45A0B3,$6D605FAD,$421C8A24,$83327849,$A2C80997
  Data.l $080AA644,$419D74A9,$B6DA3555,$34D3745D,$551AEBA8,$4B2CA155,$290E79E4,$28108425,$ED1A3AF5,$0AC61B52
  Data.l $5BAA072A,$E8BDFB86,$613B0FF6,$3B666E55,$7A698613,$1AE9A4B9,$33B666E5,$D75EBAB6,$1C733728,$8F8DDBF3
  Data.l $F390C267,$3A7CE124,$3B19C7A5,$869261C7,$7281E388,$B198FB33,$2249226C,$9DF5432D,$431F6669,$479E2129
  Data.l $E6B6A508,$C8A38E3C,$F374F652,$B98C11CC,$D3D8CF7F,$54C62FFD,$F4E9B3E7,$F0D4B033,$3D99E756,$6766630C
  Data.l $170B194A,$65ECCE35,$B40BF7C6,$F8487F7C,$CFACE9BE,$8C31AFED,$94D1B50D,$38F067E9,$93A4FBE3,$7D3BA39D
  Data.l $F66699DB,$32604131,$8EBB998C,$57C388BF,$61ECCDD1,$3FE589E6,$DB29F8D6,$5A316F99
  Data.b $B0,$EB
  WII11_End:

  WII12_Start:
  Data.l $00000808,$00000000,$68C6F1BF,$00000000,$44425002,$78415441,$CD94CDDA,$1830836D,$22DEDF86,$C18D82F5
  Data.l $42A411A4,$365CF43D,$91ED7CA8,$15815815,$605782BC,$A1585E80,$5642B02B,$BAE1FD70,$24AB5FCD,$E91F5232
  Data.l $1FAFC643,$D7891FE3,$330AD5B7,$5D9EAEEF,$727AB8BD,$C0AF8775,$3D7DEFC1,$4E3117C2,$81F8CC13,$69D0187E
  Data.l $50D7B683,$69A68F6D,$AD1699D1,$837D5056,$2CA1ADA6,$C1855BD0,$84764C6A,$F39316B5,$318471C7,$746B5A06
  Data.l $14A5075D,$7686BAEA,$D7081BB9,$72A25F70,$198075F3,$3D76EC1A,$3833907E,$DBFEB7E1,$6AAB291C,$E3AAADBB
  Data.l $ACB2CA54,$3F3CB2AA,$378EB5DB,$F2D8E492,$C56A7106,$97BEC270,$707CA475,$8AD4366C,$064650ED,$C5165265
  Data.l $F2ADED7A,$21CE389B,$C3ADE145,$E70E18DE,$6309258C,$2C87079C,$729A5D5A,$2C42A69E,$96EAD0E9,$CA5F2873
  Data.l $2C608321,$6956E138,$38E2B236,$099082B4,$BD00CF41,$71659109,$0833C39C,$3CB2CEFB,$FEDCF4BF,$E7A69397
  Data.l $F4EEBF9D,$36084716,$8C3ACE13,$EE7136A3,$B2716FAC,$6CA38FCC,$77F73C9F,$9C31E79A,$65C8BFFD,$9F3BD7FD
  Data.l $BC9CC947
  WII12_End:

  WII13_Start:
  Data.l $00000808,$00000000,$8CC07B92,$FFFFFFFF,$44425002,$78415441,$4194D5DA,$1430844E,$93777F86,$E74281B8
  Data.l $C5326665,$E5AE1710,$975BA606,$F42B815C,$AF42BD0A,$70DC01C0,$15C0AF05,$8FB50AE6,$444D41AA,$9FE89990
  Data.l $BE9349FC,$57FE3E8F,$6CDC7878,$F829E830,$F83EF82E,$AF0AF836,$3AE2411B,$ACD106FA,$BAE1EFAE,$45B69867
  Data.l $636A1D63,$AA836BA1,$1AB8D1AA,$A6D0D5B5,$D0975542,$A35E301E,$EFBD16F5,$1F47BDE0,$E0EBAEF8,$16B5839C
  Data.l $6B40D34D,$612CB28D,$44287EC3,$D8938458,$E00D79E1,$93A70ADA,$A0D167C1,$34EFEBAF,$8A2A219F,$AE0A2924
  Data.l $9A0E3A24,$9133E6A2,$F5C53160,$BF514D4A,$0CBA9867,$462E7443,$52B598A9,$4FC38744,$8CC65ED2,$6D13DFB5
  Data.l $67F753B7,$31A69319,$DA253483,$3CBBB8ED,$0CDCF297,$99BFF777,$359C5DE4,$79659067,$44233EBE,$B788483A
  Data.l $73C94AC9,$67199B5D,$5E7EDF10,$118D7F6E,$964C32E2,$E6B38645,$95313259,$CA4612F5,$C2DBE73C,$CD97F0FD
  Data.l $F8CCFAC4,$BD71F22F,$4302F306
  Data.b $F6,$7E,$88
  WII13_End:

  WII14_Start:
  Data.l $00000808,$00000000,$638087A8,$00000000,$44425002,$78415441,$CFD5D5DA,$1430836D,$B7AFF006,$9304BD48
  Data.l $540E02C8,$CB9C8728,$3DAF9506,$E0AF057A,$5782BC15,$BC5E8060,$85605642,$87BEE0AC,$AAA4095B,$9A952DC1
  Data.l $36127A4F,$81E7F1FE,$B775E5E0,$AA3794C3,$D533D533,$1F01EA89,$31E2283B,$715213D5,$87C238C2,$C030EC0B
  Data.l $1D6D0F38,$7BE8B694,$B435E30D,$47B65053,$08A83BAF,$4430A8D8,$C4063187,$0F923118,$0F7BC021,$318C1CE7
  Data.l $EBA14A50,$4FDA383A,$741B410B,$9E3A2E26,$E3D0FC01,$3AF8B57A,$92B20A72,$DB6CA46F,$736DBEFD,$8249BE54
  Data.l $5FFD5EB3,$9B9E3DC3,$48DF2A35,$526CD759,$78F0D9AF,$AA2BC36B,$55522E4A,$98DFABDF,$283D48A2,$4D377B8A
  Data.l $A6E62BC3,$2FE69BAE,$9B98AF0C,$49B5B334,$2298A211,$B6CCE7C4,$B8F1D586,$DF1E36BC,$627FAF7A,$E1A5870E
  Data.l $BE1B3DF1,$E1922167,$5BEDAF5E,$B5CF499E,$2D33D32C,$B7DFF5CB,$877F335C,$B73FFEF2,$3CA83BCC
  Data.b $6E,$88
  WII14_End:

  WII15_Start:
  Data.l $00000808,$00000000,$B1EBC499,$FFFFFFFF,$44425002,$78415441,$C194DDDA,$1030C44D,$95B73F45,$138E24B8
  Data.l $4122B36B,$A4CE0711,$472BE403,$DC16E0B7,$0B705B82,$5B8B8029,$B0B485A0,$CC4F182D,$B2D20122,$5F00E701
  Data.l $CF2591FA,$147F2673,$76ED3E3F,$7D1CF458,$7D10FD1F,$B7857D17,$9D76288D,$92648B7C,$FF38679F,$D04D3302
  Data.l $0B1941D6,$51C60CA9,$65053B41,$3119A425,$003201AA,$C14C4826,$211E0E62,$F791CC04,$0739C3DE,$D6B42D6B
  Data.l $18625290,$1FB8D806,$F117110B,$9E78E44D,$E234DC06,$2CF83478,$FAEBE8B1,$4233D69C,$4AA22CDC,$28BEFA21
  Data.l $6A3BFEFA,$AE88933D,$A411144B,$18EFD4F3,$99EDF6FA,$0CD6F194,$08387675,$6B2975D1,$4337233A,$DA211A6A
  Data.l $6E507C56,$A739AEA6,$217BF6CE,$506532CA,$6D315B96,$CE185FFB,$A0328AAB,$E5778BAC,$AEA69A67,$AC64734F
  Data.l $7E58C45C,$9E906526,$3BFB72EB,$B8324FCC,$27AA6B24,$9A189633,$28867E72,$8753BBFA,$4D39C555,$BA732F39
  Data.l $71ADD245,$86B20DC9,$F6840579
  Data.b $7E,$88
  WII15_End:

  WII16_Start:
  Data.l $00000808,$00000000,$48E1A108,$00000000,$44425002,$78415441,$C1D4CDDA,$1420C36D,$B7BFE006,$8818BD48
  Data.l $4EC8D24D,$73D0F565,$B5C541BD,$15E0AF47,$B02B02BC,$C5C80782,$AF05742B,$CF281590,$DD49C514,$D5688E2A
  Data.l $01127A5F,$F641823E,$856ADBEB,$CF570731,$3D5C5EAE,$E7C3BAB9,$F7BF0B80,$945F08F5,$FA60187E,$875DB477
  Data.l $ADD41B46,$545BAA86,$D4C68D55,$6A82B5A8,$0975542B,$2AD68165,$B0635674,$18B5AC3D,$1EFBEF9C,$AD6818C6
  Data.l $940D34D1,$12CB2852,$89BB8DDA,$4FF70D70,$06BD6E54,$E3855D30,$7229C5B1,$BBE4BE0C,$948CDBFE,$79145E79
  Data.l $652A397E,$45F7EC51,$52DABF31,$5CE505E3,$73249179,$CF09862A,$CA46BBFD,$85C1EEDD,$884DF15A,$66EDDB17
  Data.l $22D68643,$B70B7731,$F0BC6998,$66189A66,$738216BD,$5E676821,$6339C378,$E718C249,$D9D84DB1,$8BEA195F
  Data.l $91F8486F,$21928DD3,$8E2C6141,$1DDA5349,$BFF10ACD,$EBB45AC2,$419C2618,$ED4D7996,$3FEDCF6B,$971A709B
  Data.l $5833A7E6,$8C54D262,$235379A1,$ED431B04,$FCCB2618,$F9D9669D,$916B4CFB,$6618D34F,$AEB915FA,$00F9B97F
  Data.l $BC9C397D
  WII16_End:

  WII17_Start:
  Data.l $00003F3A,$00000000,$90FA5AA2,$FFFFFFFF,$44425002,$78415441,$877BB5DA,$B5D7547F,$E6FB12AE,$3DF8DDA6
  Data.l $1B1DB1C7,$63629887,$0EF42182,$481A8406,$A46BBD42,$99CFBDE9,$99CA6733,$2AF7A753,$CD0668CD,$35037A8C
  Data.l $11902124,$C062531D,$E21C6C60,$8ED7DB1A,$E49DB17F,$11EDEAA6,$FDF77DF6,$EB1B6F01,$CFB3399C,$6B7CABDE
  Data.l $76096FAD,$DE5E6179,$3939BD86,$0FAAFB35,$5FEA2572,$9C9CAFFE,$FF80EF9C,$B3997E06,$7277FFF8,$6EC39FBE
  Data.l $04FEB755,$337F31CC,$8E3B6152,$13DA0640,$7EA2278E,$4156A752,$0E1833B8,$957A2DFB,$21562858,$30A16D38
  Data.l $13295A9D,$084AC48B,$150A5486,$A8A033A4,$8F06AB5E,$72846AA4,$522E03FA,$65081327,$0AE5031A,$0A76FD04
  Data.l $C22623D5,$69DA74EA,$CA09C092,$3852B562,$954892A2,$7369235A,$4ABD48DA,$6B5080A6,$858C9E28,$AB51A45C
  Data.l $5881D235,$52721E32,$20690C28,$281384C4,$4AE0C30C,$4534AD5B,$89BD26E2,$1EFC7BB4,$5480691B,$461AA54A
  Data.l $29480CC1,$4A248A16,$16ADA518,$501888DC,$D870E6CA,$D06E142D,$E2CC7AC1,$A4AD3970,$6BA6035E,$61341680
  Data.l $582D6042,$1BC2061C,$6284C410,$341B8138,$034AA54A,$3077289B,$B04DA1E4,$1086AD46,$FB0C1DD2,$88D1B8AC
  Data.l $E04138E1,$C991A228,$09E50854,$340347B7,$85F314A2,$2C05934A,$5288614E,$752BE3C8,$611B8938,$36960D48
  Data.l $D4556061,$40B6E284,$754A9E24,$145602C6,$E9CA5041,$71E183F3,$C106B35A,$87569D50,$13D594E2,$282C7A08
  Data.l $1B0D4850,$69DB9B70,$816A3205,$144BE004,$4608B55C,$B83BC13B,$B0E02A56,$EADC6A05,$341D3870,$02A65BD0
  Data.l $471C0853,$10307A0D,$E3E12D58,$CF7F96B3,$24FEF359,$F39BDEE4,$C8C88EC8,$3781C985,$3D0EF56E,$E347FBF8
  Data.l $85ADC891,$064E4F85,$FFCC160D,$EFFAD5E6,$EA54E4E6,$1C004578,$C6E81B39,$65AF651F,$CA5E97CC,$5DDEA66B
  Data.l $0C985858,$2C365F69,$D3DFC764,$FF1D4432,$DBFBB807,$3E2B7569,$C3C2E9F8,$5452C371,$C7AEA78C,$08F63E37
  Data.l $CFBBF578,$5B79786F,$93EE6B7D,$B67275D9,$0DA08646,$FBEC7A3F,$5E5E3F39,$5C7971DE,$397BFDB5,$1B9BCBDF
  Data.l $1C015787,$BE155E3E,$8585D7FE,$686D7B0F,$4AE2CAE8,$BCFE2D9F,$BFF17E35,$3FAAE5C0,$DE5C0D7D,$A6CAF244
  Data.l $58D5F6FE,$B435683C,$54EB7ADF,$FD149480,$F67EDFF4,$CBB30FF4,$27D1E77F,$F0FCF6F3,$E55B8B3B,$A4034794
  Data.l $DBC5F1F0,$EE694BC7,$9E7EA7E6,$FDF1E795,$AFADDB0A,$835D7CE7,$1FC33DDD,$FAF8943F,$BE374BB5,$BC76F858
  Data.l $8A031A31,$B3E175FE,$B46F4CC9,$3F77ADFF,$A59CEF7E,$69A9347D,$F0F9B7DE,$F5C5CD96,$EFF7BEAB,$FBFC783F
  Data.l $2C6EEB8B,$A7BDF4DC,$ED54599F,$D1E8BB27,$CFE5D2EE,$8C237B8B,$EADE5E02,$33531A17,$AD29046D,$F54CDFD8
  Data.l $0EF64E4D,$B0BDBECE,$0F1BE7F0,$2374BB15,$7FC2D1AB,$BF97FC7D,$F9D2F6FD,$1D9BDE2F,$E37B3C9D,$539BD5EA
  Data.l $7E65B67E,$8F8AE02C,$A855ABF7,$77CE636C,$BF5DED57,$C86009F4,$7BFE7247,$C3C974FC,$CF9E73CD,$B393995F
  Data.l $8BF0E2AC,$F9C9C83F,$5DD06311,$0685E5BD,$BA7D3FAB,$7187F093,$F67C3A8E,$11C2118D,$ED0B48C4,$F39D644A
  Data.l $5F174BCF,$FEE2D7FF,$C7F07D1F,$F9BE2E0F,$9EEA87F7,$C3FCFECB,$FA67677B,$B6437AFB,$5F0B07E8,$F1DDFA0C
  Data.l $0996A8A9,$B6CB4510,$AAC962FF,$48E08A1D,$89F8BBAF,$20D6AF1F,$3F5BB37B,$E3C377B1,$4F563E8F,$2F4F0550
  Data.l $F99F5C7E,$9DC9A7CB,$9E805BD9,$DC6F3A9F,$0D58E8B8,$F2ACFC3E,$AE163FEC,$5855E5C2,$7D3FBDFC,$7D3FD7F9
  Data.l $29C02378,$42069E90,$96893FBC,$8EC9A855,$D9EF6007,$C0F2A5B0,$4CCEB020,$E20C1A3C,$A1F5A5B5,$C1F67FDF
  Data.l $D513B099,$FCAEA956,$84BF66F6,$5E5B5B51,$555A595B,$5796A9B6,$C05C5255,$4BB5ADC5,$F2CFFAC1,$11B221C2
  Data.l $7C0978F8,$CB75B261,$B87E720F,$D5552853,$8BFE5A6F,$790525ED,$4E170E5C,$25D5DA74,$8D725EAB,$713E9F9E
  Data.l $C908CEF5,$9D184101,$CDF7711C,$417AEC53,$744CF674,$DAE7AC68,$5AA4937B,$6407BA93,$793D3BB9,$76D3A422
  Data.l $97FDBA9D,$8AE1478F,$30323C43,$1485CEFF,$9094436D,$9C854306,$BF2775CC,$70F56659,$F6EE376D,$C7FF9C4F
  Data.l $1D3C6107,$9D5DCC6D,$77EBFCF8,$35A64E06,$E44E42C2,$8E6F2FCB,$7F2C949F,$4E142B6A,$4FB57887,$219BBD3E
  Data.l $6C363213,$393F6A68,$B921D413,$DC8CC4EB,$5DDD9F97,$B998A5CB,$A5E58B40,$6215B76A,$050A6532,$1062AD43
  Data.l $295154B0,$1AB1E5A8,$63F3E965,$F617EAC6,$8A7B2130,$5D73606E,$A0A903FD,$55B0B9A1,$69793A37,$A8B76DD4
  Data.l $12191AF2,$1F196A26,$648278CD,$D5183B35,$9DDF4746,$A9E8133C,$0EF764AF,$4352EBF9,$3AC64213,$75BEFD65
  Data.l $D2B27965,$AA4E82AA,$2DFAD77E,$4F7F7BA9,$E9F9CBED,$D2F5816A,$75A28357,$3657761B,$E1EDD5FA,$C360BF2E
  Data.l $7A095FB2,$173DDCAF,$BE5AED51,$85E6F525,$62B1BA29,$DBE0F6C9,$68D41D27,$E6EF6A7F,$EF709C8D,$06EDD7D5
  Data.l $E0FD1532,$1E6BF9C6,$F4DF7D5E,$DF9F0B7B,$72EBE91F,$96AD0776,$160FFDE8,$4683E616,$F77DDDCA,$4797C7C1
  Data.l $666F5D49,$F5F244FC,$3BBE3ED7,$8E1EDB33,$C9FDEE96,$FF97C0C6,$4DCEA0C8,$B3378A2B,$4AAADD83,$BB1AE567
  Data.l $438739DD,$E9EA810C,$FB593AD5,$DB61B044,$7B3939B3,$787FB4F3,$CF2EB700,$A9FEBA59,$AE77FD35,$E97B6BBD
  Data.l $7E734B17,$4383C6C8,$E8FDFF92,$31FB4D8A,$2FC948B5,$0A5ADBAC,$286D37A9,$72EA70D0,$C910A2D9,$48754A28
  Data.l $DEBE4E61,$E1FCBF1F,$FB65974C,$0B4BCDAA,$B7697D3C,$5CEF1312,$DDB2CE5E,$D92D2739,$86B37CB7,$AAF48F05
  Data.l $728B8864,$B091D10A,$9E1E33AC,$E96B0EBB,$D7C395C3,$616DFFAF,$ED0E3FC4,$EEEC57E7,$97F3F85A,$ACE70B0B
  Data.l $7D4535E2,$FDEFBB97,$D1E64BBE,$83F3E2B2,$34FE1677,$CA57354E,$583E6792,$A347DBF8,$4207A0FA,$B73D077B
  Data.l $FEBCBE17,$36385BF9,$7CBEEDD2,$19381A42,$77F753CC,$CB8F6958,$CAB0D38A,$3E257346,$E4AF24AB,$0C4F2E70
  Data.l $8137CC90,$3AAB2A1A,$AD5A9B84,$008BC4BD,$A1659B0A,$63307D73,$51FDB81B,$84A2CA9E,$4BF93565,$B5D5B673
  Data.l $E5971A0A,$C5F730FC,$B1B0435C,$AEE7773C,$75CC3F65,$34AA6BEB,$EACD4C35,$A18A179F,$CE40EA51,$0E97D2B6
  Data.l $D350E33B,$B59F5C81,$C6EE1942,$F773F1A1,$B6CA3866,$3FD1224C,$0D19B293,$CDEAF868,$7C42EAB1,$3915B47C
  Data.l $3DCFC939,$C2E5FDDC,$C7539349,$3D4E0495,$9F1ACB78,$F88639BF,$5C87CFE6,$3F764097,$4FDD8E81,$4C4137E2
  Data.l $0B99A4A4,$D8CD49A7,$10CC1F1F,$E37C31D1,$5874561A,$71BF8AC6,$4F6FFA53,$8BE647B0,$66270436,$262A9B95
  Data.l $106C0DDE,$BD7CBF1C,$FDBE8CBA,$D85ABB06,$7CB26B73,$1D38B173,$9D7695E7,$B095E70D,$5AA9D3FC,$2A18477E
  Data.l $7ECF24A8,$4F6736FD,$B5E2EA73,$26559FF2,$7C9E6B2E,$3FE6FB5C,$D68CE542,$7566B5B0,$85A2D885,$BDDADC54
  Data.l $E7273BFF,$BD3D8787,$89345E5F,$F978BABB,$2F05D64F,$5B3C77FA,$F9FEF737,$72727217,$F03CFE87,$B583AAE2
  Data.l $2E5E9B95,$10B89E0F,$94B39F5C,$9F0B2B81,$35FA81DF,$50F2B85C,$518EA70D,$77592BFF,$B153A658,$A329233C
  Data.l $A5BBDD05,$C6B2634E,$B66326BA,$D387E5CA,$DBBB4757,$9DD50B6A,$ECB35F97,$3BBCCA29,$833C251B,$27B60857
  Data.l $223F313A,$A46F4652,$F7FEC12C,$DDD1B83E,$9E8CA641,$779F0B7B,$32A7CFCD,$3F679D23,$FE387F7D,$890B4DDE
  Data.l $CDFD7E9F,$42A51FBB,$26EE1993,$C2C2DCEB,$B667FC07,$A323230A,$369501F1,$5417D61C,$97D32B16,$A52E3D87
  Data.l $D4276F24,$0BF3D41E,$1AB2F70B,$592AB88B,$15496D53,$AB7197EE,$FEFAAC76,$E3CA8E0A,$558C86B1,$686ED6DB
  Data.l $F1FC6E22,$A2A6AD92,$1676D770,$F5EB1A9C,$FDFCF8A8,$DDB1B6AB,$8021D71E,$63D89788,$CA3E7CDD,$0AE4FE5D
  Data.l $CD2C2061,$B0A3B8DD,$96FB6F36,$7BBFC7C2,$78435D90,$7E72CB98,$3822A6B2,$20B586EE,$F9BF56F7,$D2F43CE9
  Data.l $85457DF2,$870A9555,$E50FBA6B,$E8FF20F1,$CF389BAD,$9DF8CD9A,$2F4DF2CA,$7802D950,$C5FAB989,$7F54554D
  Data.l $6F6D6686,$738174A2,$E97C2E5F,$E0D65554,$F06DD4E1,$9AB4FBF5,$9FF0FE1E,$C9C375BF,$2DFF316B,$765F0D10
  Data.l $D6826856,$797D3FC9,$D1327C6D,$FAFB9FC8,$3C770B1F,$227702B5,$7C996A43,$487E5D82,$F7B788E6,$A478FD5F
  Data.l $896D7730,$0670E7DB,$52257BC7,$68DCE655,$65D9C787,$FF581157,$8454DEB9,$E6EF77B5,$2BB1CAF5,$AAC907E7
  Data.l $F1496ABC,$F4FDA261,$CC20F1C5,$FF7FB039,$BF9E4ABA,$EB408B5D,$96D8F47E,$A654E8C0,$CCA14F21,$10B4B1DF
  Data.l $37AAA951,$8686456F,$DBB9D53C,$B03BAD36,$1E214565,$ADD7EB47,$90CC6EDC,$6B3579D5,$E780C701,$57A49DEF
  Data.l $4B74BA3D,$84F76A39,$81E64E53,$50DABFB5,$07C5B62A,$9C066D33,$F9E4B79B,$3BB98EB2,$F4F6FF9F,$9C85E2A0
  Data.l $67172DC7,$2FE5FC1F,$56684D9F,$776B5A3F,$CEE0FC9E,$FBA71B8D,$991A0AEB,$33D8749E,$2E2FDBFE,$07D9478F
  Data.l $68C38CE9,$A7FFBAE9,$DABAC8BB,$9194B3D3,$6378BFEC,$8A0D15DC,$32233256,$4F48438B,$1E9BA43B,$7FC3BE5B
  Data.l $8C4A03BE,$3AD3C746,$8FD3EF74,$8FF6D52E,$762D440D,$C9CC46A3,$1761B03B,$713B383E,$F5907662,$BA7FCFFC
  Data.l $6E763D4E,$2FEBEE7A,$3CF76B3A,$D97BEFFF,$8DF7471C,$F0FFDFB7,$15E5E30C,$4630B6CB,$2C7C073E,$94ADBCDC
  Data.l $85DBF161,$F72B9EE2,$C27B77CF,$F8C617BD,$B63E57FB,$C8B13ECD,$1100381D,$BF5EDADB,$F8F4E57A,$CA76C950
  Data.l $0B9F8B22,$FEF21AAA,$89BCE7E3,$70B6FE4F,$FB7878D3,$CA89C026,$D9FAFF47,$DDC2631B,$C83FC575,$BBDEB9F2
  Data.l $B59486F7,$0DCAFD1D,$23DEFBDF,$4E520739,$6FFBFF4E,$1EF606CD,$507D9D54,$67229DF3,$8EA64C57,$2AF78EF6
  Data.l $FCDC1FD7,$EC93CE74,$3F85FDF4,$65B9414F,$C91E9BB5,$95E9FC79,$AF891275,$94EA77B7,$0C3AC6CD,$91A99519
  Data.l $F2FE7F0B,$D764FCEA,$EAA38FBD,$0FB9EE42,$FEAAC4CE,$F8F2B9FD,$FFFED983,$5FC672FC,$41BCB7BF,$7F56DACC
  Data.l $9B85EBFA,$153BA151,$2FF671D5,$EB1A412F,$A43899C8,$9BB99C9E,$D9E91782,$F75BD9DE,$9584EEDE,$E5BDC9F3
  Data.l $562A1B85,$456730FE,$EDAAC849,$EB7ED3B3,$7692EA68,$953933C7,$7800FBA1,$C3D3E7E7,$8933A4A3,$1D174343
  Data.l $E76D4E42,$75FF0B27,$53A4C4E3,$BD4FCA58,$BD467EFB,$0B2F17F1,$DCEFE67B,$13F7EF7B,$C25659C5,$BE4BD8C1
  Data.l $E081E4FB,$A993B3B9,$63B7DB81,$C9DFE58C,$FE957479,$5F1FC7EA,$F52E6D92,$BA7EBC4F,$84E0D61D,$5D518EBA
  Data.l $3D1F68C9,$E7FECC07,$D2C19229,$C0F3235B,$1FC299C4,$FC8E3CE4,$417DDC09,$E73478EC,$3A362F7B,$3BBFDEA7
  Data.l $0BF0F71C,$A6279D9A,$46EA9C03,$EC999C01,$F80B3372,$CA148EF6,$F3B1E353,$D58D3B67,$DE5FFB15,$9D4D0EA4
  Data.l $63BA49EA,$369199DD,$C6C37335,$A387162A,$489F1AEE,$A81EB672,$F32AF213,$F1B8BC77,$5521EE50,$63BF5AD0
  Data.l $DC6DCAC5,$2EF76BB6,$C89F7376,$4F12AC79,$3E189E75,$7EAB623E,$91A5A7E2,$BA5CEF5B,$35147374,$E6E9DE0C
  Data.l $B55AAE96,$B3F29F8E,$71F9C99F,$14F61639,$A77CBD3C,$CFCC646E,$6BB96993,$B6D78916,$8C9F7BE8,$F53CD76A
  Data.l $1F1F9C93,$F2B75464,$676CF70B,$B58E3A61,$BFC1F873,$4BBD7F3E,$34D4E2C7,$634A950A,$0B57F4F0,$843FB97F
  Data.l $3BD1CB32,$4C6CF8FF,$3D585A54,$32FCB40E,$B2579A59,$A3EBB2B7,$F4C70F85,$5D5CE575,$E7CEF260,$D9E90C1F
  Data.l $C35E9F7B,$6FC3FB1A,$5BDF8DD1,$F6E1797D,$1C294648,$CFE17AF9,$72431A93,$0B67CEFC,$A00F9D5F,$F1F18EA6
  Data.l $A79D5410,$A2A5F94D,$C5FCE0E0,$3FA5EAE3,$FF07EA79,$F8B885B1,$EE7745C1,$2A1D762F,$6E14126D,$4C4E74A8
  Data.l $77336C84,$7B557466,$CCF13D96,$902260DE,$B6B02AB6,$F4A380CC,$C8C79CB1,$FDC5AE37,$60FEA8B4,$5B7AFEEE
  Data.l $5991C2DC,$AF260AED,$4B4FD97A,$9E6ED733,$854D424D,$93CD65A5,$3BF85AFF,$32AD3748,$C89E84B6,$7B8FD852
  Data.l $9A3D971B,$C2CCB3F3,$688878C2,$4E272BCE,$C73A444C,$ADD787AD,$7379BB5A,$1A2DA78D,$5FCB8AB4,$3B3F62DA
  Data.l $0A55E013,$856FA76D,$509C4F20,$4BD2186B,$413CFF0B,$FD120355,$ECD0EAFD,$BAEE0BCD,$F36D4F2D,$5BD88577
  Data.l $76119656,$77FB6F13,$F4FFBE73,$B1013501,$678F1605,$D556CE60,$5E8DF2A0,$307972BE,$A310F21C,$FCA42E37
  Data.l $FE624CB1,$5CE0FEBF,$AFEFE3F5,$BE5E7760,$9887EA37,$F2D6F7FB,$2A67012D,$ECF1DC2C,$38859B13,$F5770C1A
  Data.l $97718245,$FBBD59DF,$F8880E30,$72A7EAC7,$B8B6B07E,$27994B66,$4AF9F24A,$E6FF3DD4,$0C135F08,$CB4F9E82
  Data.l $6A03B504,$8963D996,$9277B9CC,$A4DC9E07,$F779BF1A,$AB711BBD,$4EC243DD,$FAC85D50,$902B3965,$A3BD2EC9
  Data.l $BDDA6C9D,$3E3290E5,$74F2E271,$D8089532,$40B2F5F8,$610C1D3B,$8602C6EA,$6FE29D35,$2BC7E27E,$7AFF77C4
  Data.l $3FA8927F,$D9AAC15C,$F681D2FA,$A81C3E77,$CE4E59FE,$777D65A3,$48D227E7,$855F3543,$6390FCC7,$9B68D4E0
  Data.l $DD48CC55,$7CAE539B,$F71289E4,$D778A9A9,$B070DE00,$F2CD6B88,$D1BD7FE2,$F95C2CA5,$9CBB8BDC,$613BDEF7
  Data.l $7BAE9617,$8D4DB1FA,$27B399FE,$C3FCA2A0,$12221C4D,$419C84CF,$EDFAD0F8,$9779C9DA,$5C5D545A,$DB49A956
  Data.l $83262C65,$7A5E09A1,$06721F30,$F99CC7FA,$E267B1FF,$79BC5F0F,$D6433C76,$3D92DA97,$C56554A3,$FC6A66A1
  Data.l $60FF68D2,$B79BDCE6,$0687FB66,$A747463A,$7104CD6F,$33395959,$CAED7730,$AB0BAA70,$D72BCF2F,$C5FC7D4E
  Data.l $12E36747,$C6FC7D26,$425C6FDB,$B25D2D36,$8CB54776,$B98D84C9,$F3DBFF8F,$1C77727B,$94C7CE00,$A6E4152A
  Data.l $E0E255D9,$EB7194F4,$8C8D66A6,$9450A955,$C5F9EEE5,$58DB1E77,$F68E0E45,$6D777B42,$6CC75ED8,$52117C84
  Data.l $5FED96A6,$E74362F1,$B4575A5C,$B272CF3E,$21C36FCF,$BD1E9AB5,$676CE77E,$7BECFFBC,$72609ED9,$C6E6726A
  Data.l $7A7C3FFD,$6CF8C2FF,$A5F4BABF,$67D97627,$25E95F6E,$F7F61270,$FAA007F6,$E6F0685A,$94FD0BCD,$CA70A289
  Data.l $0BA5EE91,$55627B9E,$72723A85,$E5D70028,$8D116295,$AAA1064C,$50EAFCEA,$E3F55D37,$5F1E479C,$8ED9ADBA
  Data.l $2D362A8A,$7BA9A6FF,$7286E56C,$F83AAEDC,$DE9F77D4,$70ABB791,$F86D8AF7,$7D7DBF83,$B930CCFF,$2792C97F
  Data.l $5D5D3057,$55763D43,$B26A4323,$5F2E1A22,$C3DA8443,$9FD87E1D,$266F67E5,$B9990328,$3783F1FA,$75388E6F
  Data.l $C4AA07CD,$BFAFA9D6,$1F1099BC,$9583B758,$EE001F7C,$EF1BA0C2,$4D9D9D9D,$F9832FF8,$6C4375EF,$B68CEA0D
  Data.l $3F999C8D,$38889235,$1491B16D,$3CAB15C1,$197D23DD,$1BD929A7,$94BE9F0E,$726B6021,$9A476E30,$3393C1B9
  Data.l $5D531611,$E3C96DB3,$520E355B,$0674AAD8,$04A53C4C,$F6DC258A,$C8F77F68,$4CC0D8F1,$13F9F0F7,$0C532E6E
  Data.l $E628C207,$F2AC9482,$5C5EABBD,$C0CEA9BD,$AC2CA8AD,$488385D5,$E86DB6F3,$6F385EC9,$A1DBB3E5,$C66EF9DE
  Data.l $6D974B4B,$69B5DDCE,$A4EED33B,$4E87515C,$EF19EB69,$585FABC2,$E570DBB2,$8D3C7F5F,$7117E737,$AA54EEB4
  Data.l $9A74EA73,$3C393216,$D80A0F01,$57360CC4,$177EE088,$064A9ED5,$95B99555,$AB95E8F4,$D82DAB69,$1FD4B693
  Data.l $902A2A28,$FB86DB59,$22574133,$596ED683,$6D86FCFA,$AC7F7A95,$ED37BBB7,$0F0BB2D7,$BB699DB1,$EF713E3D
  Data.l $CAEDDB8B,$D1A94AE2,$0E4FA504,$4A1E9D84,$5E5B555C,$09B07C50,$3C1C9655,$BB0F5058,$92FAFCAC,$2626E6AA
  Data.l $54832597,$EDA1D96A,$B7F1B205,$5DFC4326,$175FE1A0,$173FEDFF,$95193B6E,$13A80E07,$F44FC7FD,$3299513B
  Data.l $33DFDD3A,$6E7F373E,$37D93076,$B4EEDBDA,$AFA3233B,$CBB377BF,$BC4D2162,$EC57ABC3,$68C286E4,$8282C1DD
  Data.l $E67D3F0D,$4F1C1D85,$83C56C2C,$55B0C99D,$CEBA86C5,$8E8E4FCD,$E579BF9E,$D26C2644,$4D634E50,$1A2661FE
  Data.l $D809388E,$65604896,$4A85CBDB,$272BA9FF,$E6DA6EA2,$E6FBF80F,$C4C1A2C6,$13A0CCF8,$BD53A40F,$E1AD3099
  Data.l $CA10C573,$EAE5AD2F,$5D599809,$BB9D54D9,$5EC7B1E9,$A34595CA,$8FD440B6,$D5EF7443,$DE9EEDCB,$6EA39399
  Data.l $9C13656E,$B3561F99,$0A8D1B51,$49766C19,$63635561,$2D95A703,$55651041,$3208A55E,$D7E90810,$A0C96DF1
  Data.l $D2A582A0,$4B62F8E9,$DFBA6BB8,$CE6137EF,$D62D5BB0,$6D762307,$89B3195D,$571494AD,$69844161,$491F1C1B
  Data.l $102775B4,$F57DDC06,$B8BF0F8D,$4B6C9D3F,$FCA5F776,$EFC268F6,$B5526374,$DBDD2DAD,$FB081EDD,$C3A31234
  Data.l $6B612563,$1DEA9838,$64C8189F,$A6CCAEA6,$753E16FC,$B8882AE2,$FBCD8C5B,$CD446A19,$D15B9C3C,$8BED9B94
  Data.l $227A9496,$BF8BA5CA,$4F2EC06A,$B58585E1,$F30CA96C,$B890C51B,$5AC28551,$70A013CC,$0D86D16E,$0F61153B
  Data.l $A4C30746,$E1B0D341,$D8D74AE5,$54B1BFA8,$0D5A37A6,$9C830E4A,$B3EF1A98,$525A95EB,$CF28A6AD,$C9F8E4D8
  Data.l $BB2EA1E9,$F9B1AA5E,$8744620D,$5E4A22A5,$E95E6175,$F7AB7581,$C438EE14,$C5D0282C,$3707D5DB,$6AB25EAD
  Data.l $66553EE3,$2BB87FAC,$D5A5EB8C,$ADE67F62,$12BDDE2F,$5D75F190,$4D9EEFB7,$DC3252E2,$DBB9841E,$289236D6
  Data.l $C4AF2A2C,$93328687,$8BC148DD,$D4D6B62B,$FCFE97A1,$DF93ACC5,$B3A7C4A4,$F9EEEDCC,$BB71938B,$FBECEDB3
  Data.l $6F717E9F,$E7BC6E66,$6571ADC4,$656D6969,$76421103,$48705482,$BF9B1C1B,$7157EE30,$FB4F0685,$4C9F87CC
  Data.l $EAD5B852,$E1F0BEEB,$7F61D307,$1E1F4BBB,$F98836EF,$DA6EB687,$358F27B4,$739BD6FA,$6E6D6378,$0C1ECF2E
  Data.l $089ECEF7,$6418CA72,$4CFCF8FB,$A3E67447,$E9FC2D7F,$B9F8D0C2,$51434B09,$FBCDE763,$EAD61E53,$95B93C1F
  Data.l $F15C2825,$3FCF53C8,$CEC18EB5,$8F67E67B,$437CB63D,$B45C50A5,$E2C2C5FA,$B506C462,$E3DC3256,$495307E7
  Data.l $4CEA571B,$E747750E,$A4DBF0FE,$14E3C856,$C25B5CAD,$48446DA8,$15BAEE7E,$B55B2F4F,$4BCBCD6C,$65B55D9F
  Data.l $3D1F8ADB,$3201BDB9,$4B071869,$80B66245,$5F3BBE5F,$373F1A14,$3BC6B019,$2418B548,$E5C8F8E8,$06CC1E8F
  Data.l $CE890AB5,$6D850D6A,$DA3ED138,$94CA5765,$602D521A,$65ADC81C,$9B5113DB,$435AAEBA,$6D14FD5B,$8DCEF675
  Data.l $12C28CD1,$7F6F4803,$18C3B39A,$53AD3842,$D1F9BE6F,$30BA37C7,$CDC8746D,$4AADB1D8,$1F9B18E1,$87243909
  Data.l $B3F0BEF7,$DEC6F7C7,$B8FEE2FD,$E3202F95,$7C1E57D3,$BBBDC9F6,$65094737,$BEAFADFC,$EAEB7DBA,$73E5ECC4
  Data.l $F333C393,$3F5CCFA7,$F9B25019,$666A6B26,$DDCE27D4,$81C55B9C,$ECFB6C99,$E9BC3FDD,$B259AE64,$E1737455
  Data.l $5C1ECFEB,$503A7EBF,$2789F9BB,$FD3E474A,$582D0A64,$D2C564B9,$5D842683,$C760745F,$302F9586,$DC9D6706
  Data.l $5206FFFD,$62768080,$95DDF2E2,$D7AC6C48,$3C31DA4D,$E6941415,$C3ED82F1,$C8DB6193,$ECE24A20,$CCD57D82
  Data.l $893B4692,$4E883C04,$5F955ADB,$495A58DE,$5384F5F9,$8345F320,$AC6A2404,$C5205157,$93ECB772,$B2B28212
  Data.l $A0A626DA,$12405AB9,$C1889E4A,$B2363DA7,$CDE6EE63,$317E9FDB,$4DEAF24F,$BC5D2E27,$0A62FB72,$A8FC06B1
  Data.l $D3706350,$7D2E9607,$158DA5E1,$51958CD6,$BCA5E6B0,$7DA02646,$8B61A530,$9D2868D5,$D3B4900C,$A19D5A42
  Data.l $32139F4C,$C98AA862,$52610345,$A8E010CA,$CCA3B49A,$E636CB2D,$42590AD6,$0ED623B3,$A0515AEF,$9D1247B2
  Data.l $40F748B1,$7BB9983C,$9D33B5FB,$B7D381E9,$9FEAFD3E,$57E7FCFF,$729F3BBF,$FEA9AA0B,$65CF778B,$997E5630
  Data.l $7FCFC0D2,$8235A9F1,$DACEDFA9,$0EFB9EAA,$BD5E3F18,$DF0140ED,$F2DFA9DD,$584D4D8B,$A5CBABA2,$8E6BC9AC
  Data.l $C7E5F1BC,$5F6E1367,$19094838,$F8D0C5A5,$FD17FBFD,$28463E6C,$F8650239,$7B67EBCC,$75466AFD,$0D796B73
  Data.l $6ECB7EA3,$02068426,$844D88C0,$1AA285C3,$636BE4C7,$257E6D68,$68EDEE9E,$D229B80B,$AEDF3A32,$9715D413
  Data.l $1F3113D4,$2FCAF4DC,$56DB6D57,$0AA542AA,$54AF9B3E,$5A6D0E08,$464AA7BF,$D56961B9,$791EE7F6,$EE6E9564
  Data.l $357BBF77,$8BFFD828,$F48E0D55,$C0EC3A48,$F1471C49,$B7CB99F0,$06F5CDEF,$47C4EA4C,$DFFBFF7F,$5F9FFCFF
  Data.l $FFABF1FE,$C6F678BC,$7EDFB7EB,$3F37ADFB,$F4EAF7BA,$9EEFFBB9,$A74EEC1D,$2848B153,$1DB57280,$21619363
  Data.l $EA3D14DB,$7D947046,$4E1B44A8,$7A6674F5,$BECD78D2,$B1CAFB83,$51B30BC1,$99474812,$537E3C14,$0B6611F1
  Data.l $59B4A84B,$D94C6E5D,$08EBB794,$8F6CEA96,$23A2FCD2,$6356187C,$AFC4196A,$B23E2F2B,$EECF97EB,$7DB239AA
  Data.l $4BD68D5F,$B65E6CD5,$92A4AF29,$C8D564A3,$D1EDEDDC,$BB0E99A3,$A07761DB,$0672980A,$D3E353DB,$FC5C3BC7
  Data.l $E7F7DBBD,$00A90997,$592A5321,$FD57DB65,$BCCFFBE8,$4CD2B5B4,$FB3FD730,$6C83DACC,$DB202A5F,$ED66DCF5
  Data.l $774ED7F1,$85452D10,$9FABD0CA,$78FA7FBC,$A1B28057,$F21C552D,$BF099DF4,$75F6A251,$B8CDD522,$0EE14DDF
  Data.l $74A199B8,$D5457477,$27C8ACAF,$9D230333,$BAB0EEC9,$754B659E,$8E967507,$EE7D2C58,$C07B68DA,$8DB73465
  Data.l $D27771BE,$D12ECAF8,$1B5CDFF1,$5D2C56B1,$4CEFAF96,$D545583B,$6030574A,$7EBEDA69,$526C8BC5,$BF5B2BCD
  Data.l $085ABF25,$9558EBB3,$31BC5B07,$6DF2D0E4,$8D1C5535,$4AAAB1BC,$4CEAF43D,$A88061C6,$7FF733AE,$4231D6FF
  Data.l $FAF834AD,$18DF6FE7,$3F313CEE,$1C8C1DD7,$45A8510D,$7BB79B53,$265B3967,$42DBE5AE,$E7CC2701,$E0EA048A
  Data.l $E0D68648,$EBC868C1,$ECFF9B6A,$A648DEA3,$B8991C3F,$1747D1F9,$E130CDDB,$99C378B2,$FAFCBED7,$610373F3
  Data.l $5554910C,$34019555,$29471D09,$DB8D9EF6,$DFC81FF7,$8F87E4B9,$E32BCF6F,$5F86E1AB,$84BABF3D,$22414A1A
  Data.l $491FC457,$48C952A5,$DBC4F7B2,$EDDDBC5F,$7F363A3D,$FAFA6062,$9FEE77DD,$312A938E,$973EA30C,$F8F54D1C
  Data.l $FB456564,$102DACD7,$BB596EB6,$0AF6E373,$2C954E21,$6E62F65F,$93245723,$226F514B,$F57D9A9E,$B389A9D4
  Data.l $FF5FAFD7,$1D149DDD,$27CDFA9C,$3C7EFD5F,$3B3F189C,$EBB3B19B,$13345845,$37E71755,$E97151A9,$2A79758E
  Data.l $CD8ED149,$806AED2F,$C9437928,$2BEE5FCA,$966E6B2C,$4D94E4A8,$FB744A6B,$C986D860,$CC6750C9,$9C9A1B1F
  Data.l $85C6FD7F,$42AC3F49,$BAC6C6DB,$AFFD537B,$8E4F8FCE,$3A9AA124,$058286B6,$3BED9AC2,$4793BD85,$9FFEE969
  Data.l $83B9F8FC,$845A8B07,$5A2B8775,$EBABEB5A,$199D7298,$94563691,$EB323437,$947E4C1B,$A7BB9D5B,$0B10D1B0
  Data.l $22991B69,$942848BE,$29ED0FB1,$C6E665D5,$BC57BBF5,$A792A5B8,$2BB93BB5,$A4C9DD9F,$91ED5E68,$6B0A6B75
  Data.l $956A459A,$1091A640,$DA60DE6D,$B66F2BCB,$363B9B1E,$B92A7690,$99C4D0AA,$AEED4393,$AF771BC1,$F63E189C
  Data.l $6773ABEA,$EAF0BD5F,$BF0FD5CC,$70EEECF8,$31247B5B,$A9176AFD,$23BC98D1,$231B5FD7,$72BFD68A,$0C1E1F98
  Data.l $7DDCBC20,$8266135C,$8EB93DF6,$BDFAF1D9,$C792F544,$41A55B1E,$87758D99,$BA5049AB,$5880D211,$2C575274
  Data.l $C4A8B3E0,$575B477A,$647BBA4F,$C48AEFC8,$F3382A7C,$8748ECEA,$ECE8ED09,$957AA170,$863B1611,$8755453A
  Data.l $C013ECEA,$EB43A240,$EB9BBD7E,$268FB80E,$5A429C48,$960AC5EA,$37D5EAC8,$A3514A34,$8B8E3DB5,$12D28244
  Data.l $CA54FA6A,$A304EE1B,$D2FC7123,$63B32BF5,$E3133353,$279303C3,$91A41833,$E1C211AB,$79487971,$A72D7155
  Data.l $DDF6CF66,$5F5BC545,$1541F5FA,$AF18138D,$D7AFD0F6,$3928AA1F,$BB6DC454,$2AA90A74,$AEEE40E5,$FE7CEF93
  Data.l $AE24E5E9,$F6FEDC43,$BFEFDBA1,$35353536,$6D19D533,$5A709A3F,$B1C189FD,$0341DDE3,$B8EAF18A,$C25A997C
  Data.l $860746D7,$CD1C7B07,$D93C96BB,$161C31D0,$8EDA4955,$3ABAA40F,$C15ABA02,$2E99E9D1,$4DE345B8,$475F48F9
  Data.l $8320E526,$2AC63889,$41E347AE,$FB0DCEC1,$FEFEA185,$64763F54,$62FD96FB,$4FCBF56D,$F5425CBC,$CDB99B77
  Data.l $D9FCE0A2,$4FF37A94,$F5DC38C1,$FCA37BDE,$0F8B7B6D,$9BB4DB6F,$A38E1F15,$FBDDD2DC,$F274044A,$6FD87F58
  Data.l $F615B010,$6E5753EE,$B3115B8C,$6011A34A,$F47DAFC7,$B1AE8F4E,$6D282856,$75199B69,$7B1A79F2,$F8282A3A
  Data.l $AF5F9AF5,$75477E7A,$BF237D53,$9EC770B5,$1FF65B6D,$B7923AAA,$D5F2FD67,$7EAED7EB,$0D11E572,$74B9D929
  Data.l $4BB59AF9,$44C9DC9F,$C296CEA3,$256AFB9D,$38624D28,$8572134E,$5AF7383E,$42C7AD1F,$A3911D1D,$E4F93EB7
  Data.l $6F78FEF5,$C84CD1CF,$B5DA68E7,$E17022A7,$4D14B9D6,$A58F1010,$27199E08,$5A1BCA9A,$409E0A25,$C6F3381B
  Data.l $FAE7D7ED,$DAE2BC9C,$34F86166,$EB93F178,$F74A3309,$39989E4E,$FC763335,$87575BC2,$DE4FC732,$9B9DE4FA
  Data.l $AF9D6D33,$0E2D77BF,$FF4A99F1,$99B9CDDC,$516FCA14,$E85EAF26,$6294DB8B,$B32F5D93,$BA5ECDF5,$34570838
  Data.l $7FE7FDE0,$4C6CFB73,$B0A2525A,$CE985C0D,$6DC23BC4,$8F1351FD,$CC9E981D,$361274B8,$4A09A5BF,$FEF7F9CD
  Data.l $1D96C97C,$E26C96AB,$C3633651,$C96DCF0B,$58B3BFDD,$9DBC9384,$F6ABF2EB,$505ADA6F,$A82B28CF,$3E9DF735
  Data.l $C64A9A37,$3CDAB21D,$8FC5C751,$6FD4BA3E,$4AD59665,$F1BC5F01,$26E7BBD1,$A8471852,$7555AD6C,$1E171B9C
  Data.l $6FAF2DC8,$7B8625D0,$BFFDC23D,$16265B58,$1C969554,$B2ECFEDE,$5F58775A,$6B97F6B1,$BADF6EB7,$55BCB73D
  Data.l $0BE16CCE,$57869C98,$6B4E0DCA,$C5F6EC38,$EB0F3083,$DD333D9A,$F2BC1F15,$675F54DA,$71993247,$037D3D1B
  Data.l $51D3D3BD,$E5683604,$B9DF7D1C,$40B35371,$3F219307,$7BBB92DA,$2C06FEF7,$B33C9644,$6EC582B2,$41E0E66A
  Data.l $FF9FFEDD,$7BB5A5FC,$0642451B,$2D5B4D43,$64AF520E,$6BAD2A1D,$D2ED5AD1,$DEBFFDEA,$C77B31CD,$F0995C6F
  Data.l $B3181A63,$533A0726,$CEF15D43,$C9E9A9BE,$26A713F1,$233AC6A7,$A2713A16,$4DE94027,$3E1FEE28,$EB813A73
  Data.l $AF9D52D5,$27A46867,$55DB2DAE,$0D14C72A,$D8DAF5E5,$A2D46F50,$2BAA6E6C,$B0ABBEDD,$4894D2B8,$2727FB25
  Data.l $522DFAA7,$C48A5499,$EF7482FA,$7BBF1BC5,$6EF7FDFF,$DD9891F4,$E77A5843,$3A7A7A26,$D0D4F143,$94788189
  Data.l $A228B7E0,$09322713,$50E0BB37,$F78BE233,$F559F74E,$C04EDD84,$7E3C752D,$B2B291D5,$50CF5B16,$B83FCAC6
  Data.l $9EE7B9E4,$A8DF915B,$9035E830,$DC6FC146,$AADD7EB7,$C762D52D,$4B29F5D4,$859DB6C5,$D1021A4D,$2BED0F0A
  Data.l $44F1C383,$F11320D0,$29C21025,$137BC32E,$4A1A8D26,$64CEF5BE,$ABB05948,$1DD0824C,$33B79709,$5BEEE5E3
  Data.l $42CBDCFE,$347ED5DA,$B5F9A846,$2CD60765,$48FBBD5F,$CA160485,$BFAF436D,$DAAC6239,$95FF23B2,$1AE6A6FC
  Data.l $459EBCA9,$23CC8CF8,$B48BF387,$0B1E3D3D,$0F4147AD,$A6C6C2FB,$FDDFFDE4,$224DB4EE,$37CD4147,$2D0265EB
  Data.l $2EBC7A4A,$6BD06E1B,$D6DBCC61,$70F2F173,$0E24D348,$D6F5BECC,$F1735BCD,$77AB89E4,$4CF74E6F,$F575B8DE
  Data.l $D907DDFA,$733A3F31,$3783C1FD,$9C2EE6E6,$07F5F57D,$6B1D2E0F,$594C7847,$13B5EE78,$2C569B69,$41102914
  Data.l $3D81C945,$7F774475,$3754E29A,$0F4B6A73,$A230F002,$FB4FD773,$B61B7985,$22E3C8EE,$5CDC4F06,$5D6B65B1
  Data.l $8F31D5F8,$B4A2B6B4,$15CADB78,$7EEED6CB,$45BCA0A5,$4D74096B,$B7328A9C,$F3FCFF3E,$EE712AA5,$AB2FCFF3
  Data.l $8F6EDDC3,$B0D8A91D,$6BA08B72,$9AD8DFBE,$DDF9ECBF,$6FCCF0D2,$31F65DEE,$CB940FF2,$4054C93C,$85B87E5B
  Data.l $F572BE1A,$94A500CC,$4A995AB0,$980D15D2,$68779320,$A598F4EE,$56A8A4A1,$EA1A1813,$54128BE9,$DAFA732C
  Data.l $345DB3E5,$46225222,$7F58D777,$B46AD710,$6FC7A0EE,$7394D697,$4760D6B4,$91932ADC,$CC7764BE,$4AD9CA86
  Data.l $85BB575F,$BA4DB9F6,$C85740D8,$543F2CC0,$9D9DF703,$5BEAF2F6,$4768AE55,$9560A8D0,$3A1E1717,$8D4FF6C4
  Data.l $72BE0FE9,$75804EB8,$7645EB1E,$2A8ECF2F,$A5D4FBA2,$79656973,$4BE89C05,$C5F564D8,$5DAD36BB,$CCD7FCBE
  Data.l $5DAFD3B6,$5AEA68CA,$0B84CEE9,$D8EE5457,$763AA05C,$6BB9DAFD,$8899DF6F,$46A9115A,$F15DD94F,$E3F353D1
  Data.l $EB7D5EC7,$654FB7ED,$466727FA,$E1D3FAFB,$8DEBD460,$377E7D86,$96A247C8,$D692BCE2,$2B558296,$AD60B1F7
  Data.l $E757120A,$12B758EE,$8745DD8C,$3DB0D95E,$E0D6AF37,$9C5A55A1,$EDC3FAB4,$2EE2C7C3,$4BE42954,$6BBC1AB5
  Data.l $D3C5E2FE,$CCCD8EC7,$519D4864,$51C34525,$7F6F7B6F,$F0826DD2,$C3586768,$AFCB2868,$63EDE056,$BF24E3C7
  Data.l $6326A855,$498F29FD,$2259D4A6,$96BF6EE9,$C9BBBB91,$E6F67BD3,$E2C7176B,$E1D1127E,$C834B6C1,$004E97D2
  Data.l $BF1E61A8,$1DA8D503,$0936C383,$F5EA7EDE,$7E455D19,$870F9325,$1B6F2132,$CADD5F5E,$9223B956,$AA8B3B7D
  Data.l $ED754BF2,$E60064C9,$9AE29449,$EA9A9282,$7915C3B2,$7A35775B,$A387C646,$C55A995A,$B4F44865,$EA0A1FCF
  Data.l $B1F0CB4A,$F2926933,$4D4F8F74,$E7CC71A6,$8A970E85,$2EC363A9,$BF1BE4D7,$8D79AB49,$3694B6FB,$AA2CEDE7
  Data.l $15988BE3,$717C5E9B,$3AC3B6DB,$2CA9CB4A,$D37BB9DA,$95F0D33E,$ABD4173B,$932FAD56,$8423DBDA,$A5A90444
  Data.l $3BF9C748,$AFE689BF,$DC5B955A,$57E66628,$1EE9A9C0,$4A90AB5A,$D43C1A95,$5A23143F,$E7108F72,$0C19DCEF
  Data.l $8C4EF7B6,$6B4E2324,$4C58FFA0,$FA73A8DC,$76873670,$A575D8E9,$F7AD2C45,$7358C9D8,$ABC8CE83,$62CA5439
  Data.l $BD5EAE17,$758557FA,$95A8AD32,$0F6A85A5,$AE2C2A1F,$55AEA9A9,$F4A4CD74,$1946BAFC,$30BB0D11,$783BDEA5
  Data.l $E6300DE9,$CE81DC3B,$EEA9F9F1,$CCDF6758,$9DAE37ED,$9D9F191C,$713F1E9D,$ADE5FB2D,$C1C1C199,$97B4E1E1
  Data.l $8ECE4F8E,$9EBDC7F5,$F087DC68,$6ACD98A5,$B18205F3,$B3132630,$255AAA6B,$C5380872,$A23856A9,$5A5D9211
  Data.l $18035450,$54928D99,$9CB8C1D4,$5DDB0483,$86AD5CB0,$FECEB15D,$4C49A9B4,$871E2384,$58312C41,$9A81242D
  Data.l $63D1A91C,$CEF6C9DD,$B49881EE,$170560E8,$BD9DFD46,$6C7A58E9,$2B85B8EE,$C1E108C4,$ED302DFD,$7528B80D
  Data.l $F857DEDD,$812918DE,$7B0F69FC,$6B359AEF,$662DC95F,$9EAF3041,$163C20A9,$265A5398,$B836BD24,$DF4EA0B6
  Data.l $9DEA9DD1,$1CDA4C9C,$2049A72E,$DC2CB936,$B946A2C2,$465C5011,$1F256E71,$96F274C1,$D7EB7D92,$C2CCDDAE
  Data.l $CED54531,$8A0B071D,$E072D95E,$CF873D48,$1DC81C06,$E5D49A3B,$615F5DAE,$2D08F889,$EAB6A6BF,$EADCAD48
  Data.l $B5CDE425,$A13D32AD,$A92D2A6E,$F3F19168,$B72C6ED6,$2545CF4D,$9D0C1515,$3B73E027,$CDCF26DB,$F0980924
  Data.l $BD47E285,$FCD0CF36,$C9BF93A9,$7C2F8C8E,$70607FB4,$6BEAFE6A,$AE444E23,$832EBAA4,$58E9D3A7,$38647866
  Data.l $1ACC24E5,$BB730A89,$6FB9624C,$15AFC070,$5AEE97D5,$36DF9FBF,$CBB5E577,$D83B8EE7,$BDAA5C15,$49D0E32B
  Data.l $98F9AA6A,$07F0E3DF,$A956849C,$91A99DA3,$4FD25481,$B6EE4DEB,$1923B258,$B6741A73,$B3623A44,$B6E68039
  Data.l $61E92010,$4984244F,$E52A5F61,$54644B52,$DDC461C0,$1BD864D1,$043CF80D,$884DEB02,$2FAEC14E,$39172E2F
  Data.l $B490E993,$7FAFFB70,$CA52C05D,$FDF2B235,$F6DD6CAF,$4345414A,$6DDEC165,$A94717EB,$2D067702,$BF3CA8B0
  Data.l $DA844D59,$FD697A9D,$F31BF5C6,$BF21F59B,$B7B761DD,$A1DD46F7,$992DA7A0,$0DEA1AEC,$AE1C78EA,$8F25F08C
  Data.l $9E9B1D8D,$DE9C3988,$BA9051E0,$05488508,$DA188063,$0D6E6D7C,$BCC0AB97,$C55BB4C9,$68EA9268,$489BDDB7
  Data.l $AAB29D46,$08861AB2,$8A5C8471,$56B146FA,$62C60A63,$D0490721,$643C50CE,$D7B74941,$6C786981,$098BC5B5
  Data.l $98382A6B,$BA0EDA3F,$50DC441F,$158995CF,$95CF9AB0,$D5B0454A,$0A9A3DE5,$958D39EA,$C89A0DA5,$712C4F50
  Data.l $F9091134,$1823849D,$16886274,$E5733B6D,$7DD395CA,$73AC79E0,$FD93D5EC,$0CC70A11,$0F3221B0,$48878F1E
  Data.l $8F6D5CBD,$5C954884,$88F51B8F,$3692AE4A,$F267291D,$AA2B2B1A,$29EFF72A,$EC65CA66,$56B2F2BA,$AE6D2215
  Data.l $C0DC392C,$2CB50397,$BCB1BC98,$49AEAEBC,$0C05E9EE,$45C90B56,$D1A74432,$81011411,$4E628F44,$B878602F
  Data.l $332CD59A,$1E52E4E9,$91332787,$3A7089A4,$C56EDC49,$EECF8709,$43A30408,$F4CC2F67,$A68C717A,$68842920
  Data.l $DECECED5,$4F97F3E3,$AD2DE547,$60CF6752,$B929D718,$54AA87D5,$E75791C1,$0A75FB8F,$79079731,$3ADBC68F
  Data.l $DF2976E2,$B9B74918,$C1029531,$72819371,$2100D387,$EBB5D021,$D23C5245,$AE8BBC77,$56AFB5DF,$3B1C7446
  Data.l $20709FDE,$36048172,$CE429020,$523AAC6B,$2ADD5C52,$CD802400,$5C242857,$17CE4A9E,$A71D2643,$AD8AB2A6
  Data.l $0C0899D2,$96540B95,$B2549E8E,$1122133B,$9450B704,$7A0BE9D5,$9EA96DDC,$0E14344C,$544EBC07,$AD341187
  Data.l $32652957,$3808E11D,$620C0E9D,$C0D18256,$CA5B09E0,$DDEEF773,$2B9AB075,$33765037,$AF24AAB7,$91D170E8
  Data.l $7153466A,$F5A510B9,$C2C28ADC,$303E9E32,$71CCFA74,$E8542C3F,$9C2FB729,$5288E00C,$38A01301,$EE1D1B1C
  Data.l $473AFA70,$B1134667,$11D13264,$89C37BF1,$264CAEAE,$1F744C93,$E6DBDE3B,$6D638572,$E0278F41,$4618CC26
  Data.l $BF0102B9,$16138EDB,$7529511C,$49035806,$9F1142B8,$04A2D2DB,$1149C38C,$91A5AAB8,$042317CD,$8C04688A
  Data.l $162E16E6,$96E1FB8A,$3106EADA,$353F189E,$8D84C495,$CE90280C,$FFA091B4,$4F2C51DC,$18393C9E,$A17CA423
  Data.l $1227F51C,$DE49410E,$C2A62AA1,$130DB479,$3AF83134,$E28F13C2,$9606A6C2,$448FE4C4,$48144E23,$FE9C23AE
  Data.l $7767D470,$908953C6,$B850B29D,$981BE4C9,$0709EF1C,$3858C9E3,$E918189C,$80E3F0E9,$47A23A32,$1D9D533B
  Data.l $EFD048B1,$036613B1,$77B477A4,$91900C78,$4227B674,$D1A95EB4,$A5ADE683,$142045AE,$0F617DEA,$423086AE
  Data.l $E5AE6823,$504EB823,$0914C557,$826E08C5,$4AB96215,$56D7E121,$ABEAB2B5,$30F9EAAA,$22246981,$43436B41
  Data.l $1ED6C28B,$9A8A6177,$EF77BB7D,$1E9117CE,$2AD7AE3B,$78E5B380,$D01B875B,$C163415D,$A445429E,$64AEC3AB
  Data.l $D51495D5,$16E2DA19,$DAB37D51,$06E37211,$09B97694,$10776523,$E0462D3A,$03BB4524,$585F6001,$7C79B463
  Data.l $000D175E,$953A230F,$DF54D398,$1851CAD2,$18874C70,$520DBB70,$64D184E1,$6D3C780F,$1560AE20,$74CF6F62
  Data.l $82146681,$50D740F0,$993205CA,$B74F11D1,$F6917C7B,$C8530FB0,$1E2F8B10,$CA319873,$391EE911,$64787C7E
  Data.l $E9307262,$09889446,$9448BA77,$8C7A11B0,$668E05B2,$338F6E62,$11528FFB,$C7A742A9,$54832E9C,$6D7DA065
  Data.l $104E3751,$AFA3A7A4,$B510602B,$6756F470,$1AB01A20,$06529D11,$C1CEDE61,$A3CD6063,$9C2FAF01,$09D808E8
  Data.l $E8B2E1DC,$F707D5C5,$72345517,$A08912C4,$E1C8EAA5,$64DEA95A,$CCA5A9D4,$4F2E56BA,$39B214A6,$D1069922
  Data.l $DC2A38F0,$4EEC2166,$941A88C2,$D7A6132A,$5D843199,$46C75955,$DFBF015C,$3AB49A45,$D333B46B,$2A920F19
  Data.l $86F08AB1,$AF51A2DB,$0AD16ECD,$161542D8,$43F51E48,$EBE23E2C,$E90FE91A,$8CE610A4,$11F94D1E,$62C646A5
  Data.l $50A520C9,$7C386828,$77A05EB8,$FAEA9D87,$D8470543,$506A133A,$799A5B09,$D1E82162,$514198EC,$6140E073
  Data.l $988C430D,$9646DC75,$4C587696,$E856A208,$05976E2C,$F6915C23,$D87B68B6,$480F420A,$6AE2F7E3,$B7E82B83
  Data.l $83660C1B,$1F4FEF5A,$C13D3BF5,$5F4F64B6,$13306507,$2C5B8604,$3A8E4A98,$CF84886C,$6A257161,$60FF2B2D
  Data.l $25A24B05,$D4A4141C,$51EDFD5B,$442D94AB,$68B1EDFD,$522045C0,$00E340BE,$56CDA346,$C816A937,$B68B4CB2
  Data.l $9E7F4039,$269C22F1,$48EFEE31,$129D6804,$2B877324,$93244F14,$16215C21,$674030C9,$598F21A3,$E20010C8
  Data.l $366DA564,$0907F65B,$2D90244B,$68EE9BD1,$9DD50ACB,$44758B6C,$F2E1043D,$12B508FB,$EC91D62C,$7CF98EEE
  Data.l $6244A9ED,$AC7A7A70,$1A1D15CD,$223AC4CD,$26148D76,$6082386D,$10B01D66,$2D6B1524,$C6499B1E,$14A82D28
  Data.l $BAA2F5EA,$F9F90523,$F30B87F9,$1A4719BF,$D5199A9B,$46A3C087,$65754B76,$92E1D54D,$03A0166A,$55B3113A
  Data.l $66CC988C,$BAB31E83,$08999D23,$DE1DA665,$C2AF5BB0,$B2448982,$23B47533,$6D39B0E4,$F0C76716,$6C2A70F8
  Data.l $32181143,$BF1142D8,$A4A9D09D,$858565AD,$91B96C55,$4A9368A0,$4C36D08E,$9B46CC6F,$90210154,$5524C09E
  Data.l $4DF595A5,$85451575,$66C43CD5,$053C0585,$09788FEE,$6ECF948D,$88E82805,$810406D0,$23B87B51,$788CE99D
  Data.l $651B0EDC,$E8B6CC42,$CA44C4D0,$224489EB,$54A91D6D,$00CFE3C4,$43A40EC4,$89EE3356,$E91B1FF7,$56E2608B
  Data.l $21A25F16,$43233DC3,$ED011A71,$86751A9D,$A6077EC2,$64E9C3C7,$E1D041C8,$0CC7A774,$B84A1F92,$03B09183
  Data.l $C81D8F84,$0875C0ED,$6B549480,$13487A0F,$55491722,$AD488172,$09A4E033,$4690B482,$0194EA0D,$3255A952
  Data.l $34A38B01,$66031098,$D45A5482,$2D2BA920,$144BE66F,$AB6B491A,$5835A950,$2C7620DC,$E2274A0E,$08124409
  Data.l $0218ADA5,$823490A2,$13D1064E,$D3A1371E,$D78F76E1,$01CB9466,$681855DD,$F5AB053B,$011023B8,$05061272
  Data.l $A049B9AF,$16ED38B7,$C3D7A0CC,$E8016928,$897C42F1,$813766C1,$24E5D686,$749A8920,$229C4839,$17AAD230
  Data.l $45A771C9,$050093C3,$76FD3B7B,$D611810B,$9AB0932C,$95934A35,$58B06802,$CBBF01EC,$20ABD166,$91056103
  Data.l $72546B01,$58B11499,$A2151A8C,$0815C8D7,$6DB8F769,$E4C38A98,$4E832188,$9510C06B,$14CCDB82,$61384C69
  Data.l $2E6DDBB5,$AC59E7D0,$09431236,$A5CDA87B,$4258F397,$29797308,$30270EB5,$A162D993,$EA330248,$5F365C81
  Data.l $79F3E424,$F8B02040,$D24A135A,$12B16104,$0C49607A,$6CC7F503,$082A5580,$ADF9A9D1,$3214AE4C,$2258085B
  Data.l $90142B96,$61D6A356,$F297A934,$83AB06A5,$A075ABD4,$ACB4D9D0,$BB443606,$46AB7EFD,$C40B62C0,$22589122
  Data.l $377E6D83,$3C390906,$6846D9A5,$BDB02AA5,$FCFAB285,$7D940A4E,$388650A1,$A5440E83,$AEB1FDA5,$4E870EEE
  Data.l $E2DB7B8B,$02565049,$2654B6E1,$DC3C3DDD,$DC078A9F,$65D048DE,$D7DA00B1,$BAF016D9,$859B56ED,$AD7981A2
  Data.l $E0CC9566,$240CF68C,$2E56A83D,$C3984310,$52EE0417,$1246E58A,$F95A32E6,$2A4C9952,$D1973D05,$2C842B00
  Data.l $AB6D5346,$5A4DC312,$1B085331,$73BFB4CD,$A0686870,$C95469C3,$11B30635,$AF3E1D41,$050A13D3,$D84489A3
  Data.l $FCFBB169,$746B5476,$00ED6384,$648EB1C7,$A386D847,$3B0D0006,$D5D4E5A9,$7AF448B5,$39895F19,$5512161C
  Data.l $62B95AB0,$82510EB5,$68C2DCEA,$19D00291,$294E98CD,$B80172E2,$2B547AE4,$5A2470E2,$54A54EA3,$1E62E529
  Data.l $A86CCB97,$5C258B67,$50AC5726,$CD2D7948,$D5954DAD,$0019022D,$84AB51A6,$A44C8D60,$AE244D80,$8A61A868
  Data.l $41084AE4,$6F699000,$28C7BB5B,$02D97217,$AD3AA210,$CB7C0516,$F46A3563,$2F7F74BE,$04018268,$2A0016AC
  Data.l $19EC12DC,$49A76818,$8F794D1B,$0D1F7776,$2492683B,$EBDF9769,$4765F44F,$DBF6182C,$B1A3F1BC,$8E142870
  Data.l $AD68DA25,$62C12F94,$AA2F29DD,$91FD3B33,$5382CF88,$CC3BA880,$4D4301B0,$140DA784,$ADB040F6,$F4184DDD
  Data.l $3B462346,$52A2345D,$312A552B,$1036298B,$72C31320,$051052C0,$0D45A01F,$900AB569,$2D025992,$260C1B8E
  Data.l $31C309A3,$F1E7CA58,$BAA6AC78,$509E1686,$E409E3C8,$A144B92A,$2A355302,$E5C39F19,$1F0EF54B,$515A02A8
  Data.l $C48B434B,$5EBC3A48,$C46CD5B7,$6A0B2EED,$68B25B30,$5E42840D,$0DE5DD87,$1DE2C5B5,$8EA5C120,$48954986
  Data.l $1306B06E,$AE0F36C9,$48C9AB95,$A2AA0D3A,$A071E9C5,$8F02B14A,$40FB8D1C,$162D23B1,$6945CBAB,$06032A65
  Data.l $A156A598,$81B022D4,$84FD84F2,$8708078C,$F1E52D46,$A9483A55,$6BDC0231,$6A035AB5,$56A5E102,$3532A42B
  Data.l $48466182,$C5650226,$BC80A346,$A01A0532,$952A5692,$3C60E96B,$BD31A1EA,$5B35A652,$2412761C,$3685AB2C
  Data.l $09937A23,$534703A5,$46B31E1D,$974844AE,$03BC7B2F,$1A701833,$04CD1A37,$28F41B85,$6CBB70E5,$54A34184
  Data.l $C066F56B,$14B56098,$E2D4A288,$3261E6A0,$D6A64F36,$33502ED3,$FAFABCD5,$A4CE9146,$3A805701,$A42B0CC2
  Data.l $7D4B5E22,$82894723,$92FE41AD,$D7AB102A,$22D540EF,$17C58B1E,$23944C6B,$7A5073E0,$444958B9,$8874E9D3
  Data.l $D5B486CE,$C2036D1B,$FF8B309A,$B51D3A68,$9627B493,$403DC74E,$2CA7142C,$90DC1216,$476758DE,$EF9C0DD8
  Data.l $51E3C68E,$4991AA37,$12C44A64,$01E3A54E,$EB038D17,$D6AD0661,$6CFBF764,$0DB59026,$82DA4118,$6ED39F11
  Data.l $ECE6CD25,$DDAC7B7D,$14A3316F,$237AA748,$BFD96F28,$DDD8B375,$6D65C05E,$9A484AE0,$9D32D89A,$C180C719
  Data.l $C1CC1468,$034194AD,$992A75E9,$8000421C,$0C4D2D04,$69B7ED39,$4CCDCD98,$726542A9,$39461CF8,$58372F9F
  Data.l $69076E1C,$F9B3E9D0,$5833D016,$06435721,$B16CAC1A,$02769CD8,$56CC6856,$76E7DB87,$39B4ED38,$D5B33B0B
  Data.l $20CDC365,$F6B082F9,$5A8328B8,$8D48E3C2,$8093B736,$7CB03C65,$B60B3373,$5AA86C79,$1B36E30E,$3D3AE3C8
  Data.l $095A38A8,$945AC860,$348A0820,$4EAD101B,$0ED137AF,$6FCD599B,$B44A6169,$8D299026,$31A7043A,$90A9469D
  Data.l $1EBD202B,$82701ECA,$50106201,$606EFDFC,$35AC236D,$3581DF66,$A962DC00,$E031A28E,$0B4EA377,$9B16CCEB
  Data.l $AB3D91DD,$042B8804,$19C01A68,$AB4947AC,$49A76BDB,$1247B09C,$8D1F0E89,$1A053493,$CF10183A,$468D2000
  Data.l $DA44F294,$D02122DA,$6804D203,$50DE9C0A,$1AA149C0,$4B15DEA5,$367CDA24,$DA502540,$AB065A03,$C8E5C641
  Data.l $49D05F70,$CE20E4E8,$89CFA414,$B50AE5A9,$BC25A55A,$34650F21,$0A0E9C59,$CDAB53F0,$8285060A,$2D5A423A
  Data.l $40AC09B8,$5036AD59,$E68D17C5,$037882F4,$13F50230,$ECFA21D2,$06DA2899,$80326CDC,$5EDCD981,$1442938F
  Data.l $1778232A,$019D6294,$B4F88123,$B405D805,$5A950A4F,$23501B03,$0B489882,$16F81A70,$04A90864,$D32F9720
  Data.l $72D50061,$060EEE0D,$83AB4B41,$EA84C420,$88513241,$D2812CD8,$5AB0A388,$6BA04103,$B49CD935,$B98A5211
  Data.l $00470E1C,$D4967912,$4C417082,$7EE1F198,$06051998,$CC232804,$93311688,$6B5B25B4,$081B0E1D,$904A3D36
  Data.l $820F59A4,$9C1F6411,$41BA80B4,$E5DD94E0,$68FA8171,$1024CD42,$06410F55,$623D1BE0,$0D246130,$0519A34A
  Data.l $B92118DF,$28C47414,$6B075B78,$30CE27B3,$69A709A3,$6041470A,$5B4E28A3,$EB328A69,$CE999D20,$FBA091B6
  Data.l $9B50EBD5,$F7824ECB,$121B0051,$175EEFF4,$16604498,$5261C06F,$E3C220C9,$E101B8F3,$195B01B7,$56B4002D
  Data.l $71A36ADA,$16B50514,$49F81504,$C06E9C5A,$810300D5,$3689ECE0,$900CC597,$5716C667,$F5046804,$B03D101B
  Data.l $16118E26,$3ACE603B,$3A347740,$13092494,$26C154A4,$EFEC9EE0,$20E0084D,$7C3DA83D,$D2A654A1,$C047B29B
  Data.l $0CD86A54,$60670166,$464D2818,$18310130,$A142A560,$0106E806,$A6FE3D95,$0A041233,$0D0A642B,$625B0462
  Data.l $AC5F215A,$167DF8B3,$29912E58,$23B030D4,$08345149,$9003B731,$8D91DA05,$3AB02D5F,$A5516D95,$50068962
  Data.l $41DF90B5,$A5487AA2,$256CB184,$22612102,$AD5BE008,$921A3011,$A68483B4,$EEE7B387,$0B1EE020,$94A0C258
  Data.l $CA06D5CA,$815A74E6,$4D378053,$A3535658,$9A28C511,$0238AD00,$B16D0AD2,$B31AC803,$8C31C0D6,$590840A0
  Data.l $92224850,$F627B32A,$AD5AB08C,$D6411D05,$6F500EE8,$24F66B70,$708FA81C,$60315636,$78099D27,$39E5DB24
  Data.l $D8C04E1C,$003D2028,$0D46612A,$07AB483A,$B78132B0,$452B0E1D,$08D42011,$9A08B290,$037A0D42,$8D430290
  Data.l $B8099346,$181206DF,$392F0049,$BBC0182D,$595384DE,$A0D36617,$9039501E,$1306F42A,$81366F98,$7B3A28D5
  Data.l $C1A01134,$D7BACE6C,$0B99EA08,$981503A4,$AE07640A,$11A5CD00,$BE133224,$53E04B88,$33C00050,$092839B0
  Data.l $3812B90A,$0383AC01,$60690262,$E91CB663,$03A20874,$509C0478,$6965D6A6,$D1A356BF,$0F543099,$13C5E16B
  Data.l $5E936691,$552856AB,$D2D8235A,$4E990A04,$EF80688F,$CCC91E1F,$1BD4251E,$E9000740,$C23626B3,$9A42F4A0
  Data.l $ECC6A9EC,$804820C6,$FE40699D,$7015A048,$006F519D,$1A0EC959,$A809F054,$4EED5B43,$B21F37E7,$E9028C1C
  Data.l $3971E3D8,$916B20AC,$B72E3FC0,$6C81540B,$B2EE0272,$2D41BE00,$B660D976,$334E7B25,$2A4002BB,$F8159E70
  Data.l $C01601C0,$502246B3,$9A1E7D50,$33708B2B,$1CC07BC8,$77101140,$9D7A2FC0,$E07AD016,$83A21D49,$1001ACE1
  Data.l $903D803D,$C2D1A55A,$55283980,$54A95EE0,$E8061366,$819401DF,$33207547,$62F0352B,$052E02CA,$E88237B8
  Data.l $D9134202,$64A0AD63,$59A7C0E1,$B18B60CF,$3E0B8C07,$81430E02,$E0EF0358,$1EB1B066,$FACF1EB8,$810A051E
  Data.l $20D04344,$B2050255,$3063ED7F,$9D669F64,$98CD4206,$02982C05,$902A0694,$7802108B,$2A00E002,$E2F7862E
  Data.l $320BE096,$8581569B,$A601C601,$6182EAB3,$CC82DC5E,$6755129E,$0366980F,$041AF81E,$1742061B,$94011A01
  Data.l $B8804D80,$B2B2D959,$F8792080,$2056480A,$1253651F,$A66F9788,$5FC51798,$00B6A01C,$030180C0,$830F01DB
  Data.l $666FB395,$16C02653,$1CDC59B8,$1F583F04,$0AECF4A4,$598AE2E8,$D992C199,$4D6FD15D,$5C0CDD91,$A96FAC89
  Data.l $5E049E6C,$41012603,$1407D59D,$C42FEC93,$991D6F89,$CE6AC93D,$1FD8131A,$2C202334,$D3D9E080,$6B278BAD
  Data.l $39B86AC1,$69D82C2B,$1F8B8CD1,$831CCF16,$C7F7175D,$1D94AA1E,$CA5687E6,$2B7E8CCA,$ACD17995,$32B2B7D9
  Data.l $01764767,$B325716C,$32256B39,$8416007B,$B2C422D3,$195179F4,$9BE1B6A0,$A2EDC085,$717430EB,$B3B7C597
  Data.l $B86D167F,$06A2EC28,$1F9387A6,$33F8B2CA,$DFE02B6B,$F593DAC5,$1C2B39B4,$B3A2D270,$A6A01F16,$B367DF87
  Data.l $2D1F43D8,$C6D1739A,$22EBC5C6,$F66FC880,$AC01CACE,$F4D338B2,$A8B32C2D,$FED317C1,$22D852A2,$59BDBE56
  Data.l $959E2DC4,$8B099BF7,$FA9ECCA6,$C3DDF87D,$02178BA7,$30C7FEC7,$7EFF5FFF,$34B7163B,$E9AAA37F,$DF4CA021
  Data.l $BED16378,$E6FA7EDF,$B74C6FFB,$7FD33008,$287E62AF,$2A5B7FDF,$FA33458B,$88DF468D,$C58EFFFE,$41BDBEB7
  Data.l $FE84FDBF,$F6FA618F,$F0F8FFF1,$CF7FC73F,$F98CB87E,$3FF8CFFF,$7488BFC4
  WII17_End:

  WII18_Start:
  Data.l $000010B8,$00000000,$2F269FA1,$00000000,$44425002,$78415441,$4D93EDDA,$1030C20A,$82773F46,$186AE29B
  Data.l $B95D2166,$DD2202F7,$7215ECBA,$2B90AF05,$401E0AE4,$57259E84,$626215E8,$B55C542C,$0F322B01,$5E1030BE
  Data.l $DF3A73FE,$C5B93C2B,$AF8E63EC,$C0C6B0AC,$43B39376,$5084224E,$BA3DEF14,$0E7383AE,$63185AD6,$EA0D34D0
  Data.l $FD8D86BA,$A43631F0,$B45A6299,$03D77006,$4502FEFA,$F7E51451,$C888E110,$5108BE32,$423B9915,$F9ED9FA9
  Data.l $CCF89423,$E62208D5,$6322FA6F,$D6D3B537,$0F33EA5F,$2A944767,$2FBBA9A2,$DE97B3F7,$2FD39CEF,$4E7FDFF3
  Data.l $9FBEA7AA,$4773FF52,$DE8AFACB,$FF28A281,$0DC103C7
  Data.b $5F,$29
  WII18_End:

  WII19_Start:
  Data.l $000010B8,$00000000,$CCB0026E,$FFFFFFFF,$44425002,$78415441,$C195EDDA,$1030C469,$816E7F45,$D24E445C
  Data.l $A7C10E8C,$0840D3DC,$2DB8E6BE,$A0B485B8,$0A42DC16,$E2D70108,$AF05B616,$6BC75A26,$01E565EF,$F87D043B
  Data.l $97DE6460,$B7A42466,$1F836FF7,$473F457D,$877D9EBF,$7C7A8C7B,$B2427E48,$95061868,$D747BEFB,$16DB6875
  Data.l $4D340421,$51AEBA83,$FC421555,$0C3A3E8F,$01F45332,$3F680687,$7E3C705F,$E8A8A8A0,$A27BC8EF,$D849793D
  Data.l $E3565F97,$CCDAD11C,$628FBCF5,$CA265176,$796DE639,$FCC89980,$1ADCB9CA,$9CD13CB4,$3A573DCF,$F52DF65E
  Data.l $3AF3E46E,$17BDE1A8,$EF71DAD6,$48673944,$E7CACBC7,$BE62237D,$2F1D767D,$CE76B76B,$E5AECCE7,$29E92F99
  Data.l $D65E2B61,$4275CC6F,$FC34FF4E,$0EDA0575,$9FD077EA,$092F0DB5,$14A57772,$237BC76B,$A292DE8D,$8F5F2FE5
  Data.l $AFA973A9,$A1D4E6D6,$322BD3E3,$E73E277D,$CBF2D41E,$FAE6E92C,$2FC758B7,$2F83D9EB,$3A6FFA2A,$84777701
  Data.b $3D
  WII19_End:

  WII20_Start:
  Data.l $000010B8,$00000000,$CB004280,$FFFFFFFF,$44425002,$78415441,$3196EDDA,$1030846E,$A45D2745,$822A5634
  Data.l $D2ADA229,$445102E7,$C0AF729B,$AE057215,$807215C0,$859ED228,$5815EC2B,$6C8EFE7F,$8C581644,$0534BE3B
  Data.l $67ACDE5E,$F3E6333C,$AF48CFEB,$CE6F675F,$20F6AE3E,$7E7AA28F,$0D0ABDA2,$CA2EBAEA,$D395B6DA,$D34D24E9
  Data.l $52D75D48,$65949555,$41C38729,$B4BBF76A,$FF0EEACE,$C728ECE4,$79F9A44A,$5BF9F397,$A25AED76,$7F3D29C2
  Data.l $B0A2ADEB,$E21EF34E,$3CF36B78,$94148B7C,$17CB4AF7,$38BF9E45,$5069EB59,$D3D70958,$4E66D6F1,$87F54FBA
  Data.l $5F8D2195,$C095E7B6,$7892799E,$BC6332CA,$8E53B9CF,$388279E3,$A66E7F43,$A92D9657,$5C7E78BE,$C42AE637
  Data.l $36C7D4B5,$F9166B3C,$ECCC0463,$CF5E2EB2,$4FD6AC87,$154961E8,$33D9E7AF,$4F0694A0,$3A411A0F,$C7DF341E
  Data.l $6574A1BB,$7CB17F3A,$41EA2F58,$7B3A6A39,$55FA3C71,$483C0ACF,$6ABB0B1F,$F0C5FE6E,$C3319DC8,$3DD3DFFD
  Data.l $E561F2DB,$DF4CED6A,$30FCB1A1,$CF9E437F,$8F96E18C,$F8119E58,$5367195E,$19E2A47D,$2ECE1501,$AD7D9EEC
  Data.l $FBC34C79,$CC338C1B,$344E2E4F,$E4DD4F3E,$52FFBCB1,$B193DBD2,$0446DEF8,$26FFF929,$B3A5F229,$6D866E6D
  Data.l $1ABF8FC5,$7BFEF1E9,$6BBF3D7C,$005D7A57,$25D1C1EA
  WII20_End:

  WII21_Start:
  Data.l $000010B8,$00000000,$CB7EB7A2,$FFFFFFFF,$44425002,$78415441,$4197EDDA,$0C40C34E,$890ECD45,$4935620D
  Data.l $62BA8167,$CA1005CF,$90AF6596,$5C85702B,$00E05721,$C9672908,$30857A15,$13B2C7EE,$27AA2685,$8D2C0842
  Data.l $7EF34CD4,$3D8F1E3D,$B8F97E7D,$A7BD93A5,$D3C690F1,$6BA2B8D7,$C1BBBB12,$B60C27B8,$A35C1861,$BAEA7BEF
  Data.l $A5B6DA8E,$AEA869A6,$8AAAAA6B,$353DFBF6,$D3EA7BE9,$A5FE0668,$A8740E34,$47B7DA89,$E95F1E3A,$C5837EDF
  Data.l $64C5DBB8,$58C7C33F,$96514596,$0F25B1AC,$8B66E72F,$76C2B193,$8D3978BC,$FC6BF313,$874CF1F7,$F3B05064
  Data.l $34A0AC6C,$1CF2F2E6,$A0A010A3,$39926251,$B5533D9B,$0FFC3C5C,$37882341,$9ADBECD9,$D979394D,$463EF625
  Data.l $6AAF1A8D,$FFBCF6FC,$95E75E5E,$82AB2D07,$CBBF7402,$99AF0F73,$6307DEA1,$09D2EB88,$8156F1F6,$47FD4DF7
  Data.l $ABCF6D5E,$77877202,$1575F854,$F8DBC7D0,$6542F649,$79F9C79A,$F83F9230,$A19C8CCC,$78F9F8A5,$F0B09EFB
  Data.l $FDCE6758,$BE478FBA,$E9D8D988,$FFAA967A,$2A56BCE5,$593C29DD,$A978ED85,$5053C85D,$EDD64FDA,$27B78F9D
  Data.l $DCF8D415,$97835F9C,$8969EE97,$F46693F1,$F1F5ED7C,$DFC015E3,$8CD2DD69,$F2F0539E,$5A342DD2,$5B7527A2
  Data.l $1EFE78F6,$09EDE5E5,$F7ADFA92,$BA57F619,$3728ACA9,$7B15B7AF,$5D3D146B,$E79FB4E1,$B44FE7E3,$E0896E76
  Data.l $E5E03EBA,$1BDEC145,$F1DB33A7,$F65D93B6,$FFCBC63F,$FD04FB15
  Data.b $C8,$0C,$44
  WII21_End:

  WII22_Start:
  Data.l $000010B8,$00000000,$A238091C,$FFFFFFFF,$44425002,$78415441,$CB97D5DA,$1030C44D,$121B8786,$892DC417
  Data.l $EE27280F,$B9568034,$D216DC72,$85B82D02,$080140B4,$85A4B529,$3078216D,$177BF1A3,$D231163F,$FEFE325C
  Data.l $33C7B1D8,$DE7EBC39,$287DB7C3,$F2FE527F,$0B7037E3,$DA770F64,$DA3B411F,$BE45EFBE,$EBAC1B6D,$80B2CB0A
  Data.l $79E61294,$609A6986,$2A90471C,$B9729B0E,$1F949BE3,$2C0338E1,$3A70CFEF,$317FC1BD,$88418621,$8E3A7C76
  Data.l $7A595ED1,$718F3E44,$D35C58B4,$2D0C3F7D,$AEBB3D78,$3463EB4B,$23CE5FAC,$42FB168D,$AFF17D7A,$F9EBCA57
  Data.l $FB3478A7,$CE9E4D49,$55D1CE07,$6AF6B108,$D052794A,$86168F34,$2EA9A7B9,$A3258F6F,$FCF36D33,$ABBC9AA6
  Data.l $67286382,$F3C535FC,$F7B78CBC,$BFB4CE93,$D33CD686,$79B50A39,$1EDF8854,$057B78AD,$D3CDE3D7,$C17FD263
  Data.l $97CB1913,$B999BCFA,$E6FCF666,$7FBC79ED,$E7B59073,$9C6B0899,$C3E32853,$5235B5F3,$EF3CA50A,$A663BD96
  Data.l $6B176A42,$E96DEEF0,$2D70B4D7,$B7BBC1AB,$B1D3DBB5,$0EA1585E,$571C1D4F,$3F20CE2A,$27FEFCB7,$1AE7B79F
  Data.l $9BCCA9EF,$09419FC5,$EE65D7EF,$BB8EBB29,$AA4A7C5A,$CA5BAF76,$525A7A87,$9D73F930,$3C3E3D66,$36D5DFD2
  Data.l $899FEC7C,$2AD2EAB3,$7BC7CB9C,$51EB4BB5,$FB1D7F29,$033B7902
  Data.b $74
  WII22_End:

  WII23_Start:
  Data.l $000010B8,$00000000,$10A3EA45,$00000000,$44425002,$78415441,$C197D5DA,$0C20C56D,$A55BDD40,$02DEAA5E
  Data.l $7A9CAA1C,$955502EF,$857F8F6B,$5815D0AC,$80742B21,$C96652AA,$14857F0A,$6F805142,$524D4F93,$902F92D5
  Data.l $C6318C67,$BAFB7D79,$8D3E4587,$F97D193E,$05B81BD1,$4E770F2F,$95A9C11F,$3A599E79,$E38C134D,$8030C308
  Data.l $BEFA1AD6,$A0EBAE87,$66D05B6D,$7AA3261E,$3D192BB6,$1807A9C1,$7CE19E3E,$23FF877E,$4A23494A,$45ABC3ED
  Data.l $4294BC72,$DF3BC5EC,$F2DBBB72,$39DBC39E,$349488B1,$CF8FEF4F,$7269B65B,$5F1CB9F1,$F5BCF8C7,$5C42F2DF
  Data.l $E4F187CB,$F8823EF3,$D7DEE119,$3C05BDE3,$5393B087,$F2E51E2A,$BE3508EB,$8F1E4F1D,$52527159,$6C7CB875
  Data.l $65D3C5C5,$2E058955,$CDA79E1F,$3BB1A6EB,$E5C1B128,$6F5E9CC3,$587C91F6,$FACDDCD5,$DF9FDE0B,$439C7CF1
  Data.l $E32E1CDC,$D94FEF2F,$115E3CEA,$32AF0C72,$558F37B2,$BCECDFF5,$8CBDA79C,$FC3EF96B,$3BD8239A,$706EFDB9
  Data.l $89CBDCF8,$E05A9CF9,$B88561F3,$CF496FA6,$F78F06B8,$F8F6786E,$BDED3517,$1F5E3C38,$FBC51CED,$BA797378
  Data.l $D72BA777,$9E0D62BA,$AFD2D0EA,$45DD7EE2,$7B9F0EBC,$E608A93D,$F06AC5FE,$FE949E69,$A3F9F1ED,$C2A31BE4
  Data.b $D8,$E5
  WII23_End:

  WII24_Start:
  Data.l $000010B8,$00000000,$3F360512,$00000000,$44425002,$78415441,$C197E5DA,$1430820D,$266F7F86,$E1478C5E
  Data.l $77793860,$7AB86301,$70560564,$0AC0AE85,$984C600E,$01581585,$86D36A5B,$2AF2DB50,$2F27F898,$07EF9421
  Data.l $E3DF6BCA,$D16E7D72,$C8E3C1EB,$158EFCE3,$6DDA50D6,$43201C64,$523AEBA8,$BA834D34,$155551AE,$CB286318
  Data.l $239E7912,$3E3032CB,$EB07868E,$14789DC4,$BAA04A28,$37B6D09F,$02E52984,$AFBCE341,$49269A6B,$F59E5E7C
  Data.l $3D3DB071,$3972179D,$E1E7C6D8,$5E54A3ED,$96E78439,$3CBCA822,$6CCDE50A,$63DAF2A2,$F2A25AFA,$E7E4AFAE
  Data.l $CEFAE889,$09C7E39E,$6C5657B9,$A14A935E,$F5E34599,$9AF7DA9A,$4DE540E2,$EA78A587,$5379D20C,$9A9AF2F3
  Data.l $1F5E1F9F,$F852B3BE,$8F1DB369,$62FD67FF,$7787F9FD,$C3E7365F,$F3B0E46B,$5DABCE99,$F7B79C7A,$47E766CC
  Data.l $087D65E3,$DDCC5CEB,$7B6F0635,$EABCFB7A,$DBC69B9E,$B393E773,$DE54DEF9,$1B6257F5,$2A755577,$EE5BAAEF
  Data.l $BFC7E715,$938A8A00
  Data.b $A9
  WII24_End:

  WII25_Start:
  Data.l $000010B8,$00000000,$9F157D66,$FFFFFFFF,$44425002,$78415441,$B196EDDA,$1030C20D,$121D3F45,$0A75A20D
  Data.l $059E8A94,$994B7210,$2B02BC15,$C0AF0578,$B3290800,$60AC8578,$E85138CE,$8310BE10,$C2FD27B8,$91D9DEB2
  Data.l $A78EFB15,$AE0F1ADB,$D0E51D94,$06258167,$2D94AB36,$04212252,$68F7BC56,$39CE16DB,$8C616B58,$751AD681
  Data.l $3CD2C35D,$B886C53C,$6341A512,$A3D97700,$AE34CEEB,$F9E03008,$57DA5555,$D7E1538A,$3027F2FD,$0BEB2954
  Data.l $DF3FCADF,$FCE5D14F,$ED3F1CDF,$BFE4A95C,$5F0A615F,$9FEEE4F5,$F1948FEB,$FB732AC7,$820B1F72,$1CC61D20
  Data.l $E2C7061D,$C9FDF9F9,$F3C2FBF3,$A1915EF3,$F9F9E1B3,$CBFAF327,$354FEB3F,$D0DE077F
  Data.b $6D,$11
  WII25_End:

  WII26_Start:
  Data.l $00000452,$00000000,$30B0C8E1,$00000000,$44425002,$78415441,$FD8F1DDA,$0077134F,$1FB26BC6,$80FEE3F6
  Data.l $819440FD,$E304274E,$E2D6E00B,$2B150C1C,$8A14BCA0,$4B68E3D7,$BDB5CAEF,$B969577A,$7BE95F6F,$AE3BBDAF
  Data.l $168E5A3D,$0C837159,$6A2D08C6,$28821568,$3248BADB,$93365B89,$5FD92E6D,$93CF66B1,$F3E7B7E7,$674F4F24
  Data.l $F7B5FB7B,$B6FEB264,$46B42FBE,$3207CD6B,$D558EC99,$FFB26D7D,$BEF64C73,$3558D10C,$B38ED575,$85B3FDAA
  Data.l $EE7B2A01,$B7C92295,$8E94BABE,$F00A2BCB,$1E9BE2F0,$C954F97B,$4143FF29,$5A5DACBD,$FD6D7FAC,$F280DDF4
  Data.l $D1F8ABAF,$7C7FB019,$B5727CBE,$AE5ABB5C,$953FDD5B,$6F026A3C,$217FBA15,$86CE3FF9,$F84D5ACA,$D3FCA148
  Data.l $3F585756,$D5BA3F69,$C3FC6BFA,$F90ACFE4,$F01AD92F,$15286E16,$8BBEEE9B,$6DFF0F1F,$0DFA5DAD,$BDDA58BA
  Data.l $1594AF2A,$A2A2955D,$72D6B2A3,$22BC52BD,$356F952F,$3FA8FF2C,$381EFCCD,$CFE6BD43,$DF2CBFF6,$137E913E
  Data.l $F0E878F9,$CC47C0D9,$75BE7F11,$775DC8F5,$391979E7,$508A5781,$01B8752D,$2B2BDBD5,$E1C1A73D,$FE3D70DA
  Data.l $F1A991E2,$5087E96E,$70FE7C8B,$3A8E7551,$282F3B28,$90570F97,$A7E96D46,$7BA6ADCC,$6D23F62F,$BB07ECE7
  Data.l $3B9C8501,$74B5B0D8,$B89F0F24,$B4A0CD15,$C9F1BD1D,$19A7D5DD,$B8BAF1B8,$72BB66B7,$CB3C2891,$CC1DCD20
  Data.l $5D08B6CE,$2F3DC6B8,$1D4B90A7,$1672EDFE,$B601DCBB,$6D2D1777,$7BCB75E7,$E69E81EB,$5BC799DE,$5CAAE9A2
  Data.l $19B4A0F7,$A19F1587,$5E4D9DF9,$2F8EDEDF,$4D6715ED,$D2E89D5D,$A994ADD3,$BE0955B3,$478DF27B,$8FE96F25
  Data.l $BBCC5F7E,$C7CF8A54,$D666C284,$92A5F831,$CA3F1E90,$1BAEA139,$CEE299BA,$53EB60BA,$B60F520E,$AD4EB236
  Data.l $5C1B57B2,$56B1AC2E,$CA2F66E8,$D37257E5,$CFB290E8,$0B17CC10,$AAA8D38B,$2F0E6357,$7C64AC6D,$B7651DF0
  Data.l $1FE527D6,$A0644E8A,$88F1107B,$01F3F20F,$A6FBBA93,$AFCC4F1A,$30F92D7C,$DB083548,$DF6B8B63,$F809F82E
  Data.l $804C20F6,$5E72CACC,$43D49AF4,$90C9D1AA,$84E7CF98,$A88C8120,$223DB360,$E698B57D,$00E8CB68,$9C205184
  Data.l $FF5865CC,$AD5A84E4,$C3BAB51E,$152939C9,$0D115B76,$B1D137A4,$6190B494,$7EA33683,$E9313B54,$B4A4E665
  Data.l $3329FAC8,$362CC066,$2AAD9457,$305876E0,$F94C48CC,$E3810942,$34C36018,$0CD198D0,$0924B484,$46184071
  Data.l $6C3AC354,$220ACA32,$7A92F11F,$9E086A8D,$5CC2C3A0,$6E63E246,$35A90742,$39387B26,$04E52B3B,$5186154F
  Data.l $825F3DCB,$C619C513,$10A3634B,$88745182,$69B2654F,$A3E34236,$7DF8D8F0,$E7484857,$B6EB22B2,$61EA0D9B
  Data.l $09E93E2D,$113E3130,$ED7038F5,$48188C08,$61441610,$2DA61626,$5AD1A428,$D324C029,$05C482D2,$D101A4BD
  Data.l $53904F8E,$7294417E,$934A3649,$A9AC08E3,$17965112,$79CC7C93,$B5EBD71F,$049C9C06,$B1CB04B1,$D56D3711
  Data.l $304323C2,$5C02BA4A,$63E29D32,$F5C49A01,$A71B0688,$1246315D,$0A171CD2,$4101B302,$C50A8A51,$8B9F8904
  Data.l $DA1E4227,$4E04A04A,$9338814E,$48B9E39A,$F4249A64,$2660CC3A,$213A6440,$81DFAB84,$6046C085,$EEDB8D48
  Data.l $5141E347,$8B98D864,$350C5126,$40E923DC,$BCB31188,$6EDDF820,$EA88C99B,$300DA48D,$22E5844C,$387028D1
  Data.l $326E18AC,$4BE5C0E0,$CF38F1F0,$A69B8178,$9D71B026,$C820D019,$0F29D5B1,$674C0E00,$859D1144,$32C22002
  Data.l $FBF78661,$1B349780,$038ADC70,$1FF0284F,$121BFAD4
  WII26_End:

  WII27_Start:
  Data.l $00000AC8,$00000000,$4522D126,$00000000,$44425002,$78415441,$CD95BDDA,$1040C34D,$821B8785,$D64FEC0B
  Data.l $3946C076,$4482E271,$8E572801,$D02DC169,$0B705B82,$0D25C014,$485B84D0,$9F9F660B,$91103B16,$49E4ED64
  Data.l $DF8F5DA3,$3B3358E7,$D7DBEBCE,$F4FA7495,$C5E3E8F1,$0B8F93C7,$752094B9,$061078CD,$A8EDB6D4,$D6469A68
  Data.l $75D4B5EB,$4955552D,$5CB29659,$58B1652E,$4BEFE548,$F16AA3E3,$B2563E4B,$8FEA452A,$DE6CD967,$D79CB7E5
  Data.l $C52ECCBE,$79DDCE71,$33312DB9,$733C1735,$D5ACF82F,$6661DADA,$CF1EFBF7,$49659331,$E158A692,$DBA94E73
  Data.l $C39CA55B,$97399655,$B58249A6,$E738E3A7,$E1245E66,$4AD6AB0F,$EE8E0D69,$863DD2B0,$6B18D6B3,$D20F62C9
  Data.l $EEB46339,$1810A8F7,$2070C77A,$DC24098D,$3B0704F4,$C2902782,$8E33D42E,$5438240B,$F0A77FA3,$6CD0ACEE
  Data.l $73C54DB6,$B742E124,$AE3E8F71,$8004F0C6,$B1633BFB,$E8E07D1C,$3E295385,$67BB7023,$29E38E3A,$CF1C8782
  Data.l $A390E059,$492E3A67,$D0780358,$09E85061,$A39CF038,$2DCC3929,$6B14316B,$2A76E614,$534F3E6E,$FBB80CCE
  Data.l $964C851F,$79E629A5,$9D7C2E1A,$E5C0E278,$FF31C89D,$78F3F7DF,$87D1E7AE,$E53A2F3C,$F90FAF39,$DDC71A3F
  Data.l $87073A74,$B905172E,$E9F5E0A2,$C87C5638,$73C5461D,$C89C8720,$1F61B9E9,$E491CF4E,$07391329,$E26E7FB7
  Data.l $E7866FB9
  Data.b $CC,$17
  WII27_End:

  WII28_Start:
  Data.l $00000958,$00000000,$803AA3BF,$FFFFFFFF,$44425002,$78415441,$CD94D5DA,$1040836D,$44B72785,$0C2060B9
  Data.l $A7C8817F,$0749729C,$5A39AF91,$E0B4054A,$16816816,$AE2E4052,$02DC1685,$8ACBC7D9,$6648E475,$D2790F8D
  Data.l $0DF30C2C,$FB0ECEEC,$2771FEF6,$3D8CBEA3,$B1F97B1B,$AB15B91B,$24F69EF0,$86186834,$7BEFAC8B,$D2F7EFD9
  Data.l $6DB49D75,$C8D34D2B,$F591B366,$89AD2D7A,$1DAC6F4B,$5B6325F0,$DD2236D9,$0E1CABE7,$352DF93B,$A53BCBFA
  Data.l $516ABC79,$823AA594,$C6EF2977,$5428BCF3,$7A3238E3,$71C66230,$5E1E3CCE,$2A99669A,$32BF2EA2,$9CDC3BE2
  Data.l $186ABC79,$792AB1C6,$7939E5DC,$E925974B,$0F864124,$48E0451F,$11A1774D,$3F908C29,$0DCE396F,$6A2B843C
  Data.l $ACA82490,$B19C7F1F,$A127915A,$B3D6A7CA,$DBCB9FF5,$C020D50C,$CF13AD38,$311D4FC9,$310EC79F,$59600412
  Data.l $F2C4CC49,$F0F9C76E,$9059CA69,$A5715EC7,$FDC7BEB6,$DFA3C3EC,$FB3C88A2,$430C6B02,$25F0E88C,$D617EC78
  Data.l $FF1E0937,$A2F84BA0,$14D432C8,$A38FF271,$9FD43FDC,$ED89E7B7,$146AD53D,$E753AB78,$9BBCF9D5,$551EBE09
  Data.l $CE9CE755,$EA307C3E,$28CE3C3A,$3CBD75F2,$9EBA8C8F,$C7FF9178,$CF54D557,$B06679E5,$C1AE441B,$04BDFDBB
  Data.l $EA310DFF
  Data.b $BB,$DA
  WII28_End:

  WII29_Start:
  Data.l $00000958,$00000000,$EEAD4D74,$FFFFFFFF,$44425002,$78415441,$BD94D5DA,$1030C36D,$825D2F85,$A9A3FA34
  Data.l $AB815B3F,$41B26954,$81A536A0,$BC15A04C,$0AD05682,$678D2019,$415E0AD1,$210BD3E1,$48463F39,$701E452B
  Data.l $3DF77904,$7C523C08,$91B97E7A,$EE266F51,$C47C3C4D,$558B5C95,$13B8CB74,$C30C3406,$BDF7D145,$E9070E1C
  Data.l $B6DA4EBA,$A469A695,$6ED96BAE,$BA9AD2B7,$01DA26F4,$93B1325F,$BDD2235D,$B8F1CA3E,$D1B4B997,$E4EFAB4F
  Data.l $965D6BC6,$2CB2A67A,$170E738A,$95AD759E,$24946C51,$9E45175A,$3CBEFDCF,$A342D659,$AD295E53,$274D2CB3
  Data.l $F5AF1B87,$7707456A,$D078074B,$B31E4249,$87C38228,$8C62C087,$9983C88C,$7479FCCF,$A852AC11,$8148A326
  Data.l $C3CBED21,$A7E47961,$F861D615,$E9E77699,$DDACC100,$8041D637,$79FDE6D1,$AF63CC32,$F2462AE8,$7CF4E398
  Data.l $FF6C3A79,$39D83678,$F4D2E479,$9EFF1E52,$D4E1A852,$C3C00F78,$397CFB87,$93AA0C8F,$B5E718E2,$63BF8F24
  Data.l $FD3C8A3D,$A7659E79,$6F2B8B6F,$D7AD0A3B,$E4EC519B,$62FAFB54,$6B93F0B9,$4D46A9B3,$DA17F9FC,$FD460F9D
  Data.l $96555F15,$CB2D69C7,$EC7961C3,$F1FFE458,$11B89FB6,$5474F3CB,$77696FD5,$F5FDDCFE,$CB01DFE1
  Data.b $AB,$BB,$DA
  WII29_End:

  WII30_Start:
  Data.l $422C3932,$5F6B6361,$6D622E31,$61422C70,$335F6B63,$706D622E,$6C75422C,$5F74656C,$6D622E31,$75422C70
  Data.l $74656C6C,$622E325F,$422C706D,$656C6C75,$2E335F74,$2C706D62,$6C6C7542,$425F7465,$6F74746F,$6D622E6D
  Data.l $75422C70,$74656C6C,$6169445F,$622E3167,$422C706D,$656C6C75,$69445F74,$2E326761,$2C706D62,$6C6C7542
  Data.l $4C5F7465,$2E746665,$2C706D62,$6C6C7542,$525F7465,$74686769,$706D622E,$6E6E452C,$5F796D65,$2E315F33
  Data.l $2C706D62,$656E6E45,$335F796D,$622E325F,$452C706D,$6D656E6E,$5F335F79,$6D622E33,$6E452C70,$796D656E
  Data.l $345F335F,$706D622E,$6E6E452C,$5F796D65,$2E355F33,$2C706D62,$656E6E45,$335F796D,$622E365F,$452C706D
  Data.l $6F6C7078,$6E6F6973,$7661772E,$7078452C,$69736F6C,$315F6E6F,$706D622E,$7078452C,$69736F6C,$325F6E6F
  Data.l $706D622E,$7078452C,$69736F6C,$335F6E6F,$706D622E,$7078452C,$69736F6C,$345F6E6F,$706D622E,$7078452C
  Data.l $69736F6C,$355F6E6F,$706D622E,$7078452C,$69736F6C,$365F6E6F,$706D622E,$7078452C,$69736F6C,$375F6E6F
  Data.l $706D622E,$7078452C,$69736F6C,$385F6E6F,$706D622E,$7A614C2C,$772E7265,$502C7661,$6579616C,$2E315F72
  Data.l $2C706D62,$79616C50,$325F7265,$706D622E,$616C502C,$5F726579,$6D622E33
  Data.b $70,$00
  WII30_End:

  PBData_CatchInfo:
  Data.l 30
  Data.l 165
  Data.l 215
  Data.l 223
  Data.l 211
  Data.l 245
  Data.l 237
  Data.l 226
  Data.l 222
  Data.l 218
  Data.l 217
  Data.l 354
  Data.l 364
  Data.l 335
  Data.l 318
  Data.l 334
  Data.l 364
  Data.l 14348
  Data.l 222
  Data.l 321
  Data.l 420
  Data.l 467
  Data.l 425
  Data.l 402
  Data.l 329
  Data.l 234
  Data.l 1100
  Data.l 446
  Data.l 406
  Data.l 399
  Data.l 430

EndDataSection
;}

